@@ -19,13 +19,13 @@ def aggregateFields( type, major, minor, sp, aggregator )
   Processor.new(xml, [aggregator]).processFields
 end
 
-def generateVersion( type, major, minor, sp, aggregator )
+def generateVersion( type, major, minor, sp, verid, aggregator )
   dir = "../src"
   xml = versionXML( type, major, minor, sp )
-  cpp = GeneratorCPP.new(type, major.to_s, minor.to_s, sp.to_s, "#{dir}/C++")
-  net = GeneratorNET.new(type, major.to_s, minor.to_s, sp.to_s, "#{dir}/.NET")
-  python = GeneratorPython.new(type, major.to_s, minor.to_s, sp.to_s, "#{dir}/python")
-  ruby = GeneratorRuby.new(type, major.to_s, minor.to_s, sp.to_s, "#{dir}/ruby")
+  cpp = GeneratorCPP.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/C++")
+  net = GeneratorNET.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/.NET")
+  python = GeneratorPython.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/python")
+  ruby = GeneratorRuby.new(type, major.to_s, minor.to_s, sp.to_s, verid.to_s, "#{dir}/ruby")
   processor = Processor.new(xml, [cpp, net, python, ruby]).process( aggregator )
 end
 
@@ -34,6 +34,6 @@ aggregateFields( "FIXT", 1, 1, 0, aggregator )
 (0..4).each { |i| aggregateFields( "FIX", 4, i, 0, aggregator ) }
 (0..2).each { |i| aggregateFields( "FIX", 5, 0, i, aggregator ) }
 
-generateVersion( "FIXT", 1, 1, 0, aggregator )
-(0..4).each { |i| generateVersion( "FIX", 4, i, 0, aggregator ) }
-(0..2).each { |i| generateVersion( "FIX", 5, 0, i, aggregator ) }
\ No newline at end of file
+generateVersion( "FIXT", 1, 1, 0, 0, aggregator )
+(0..4).each { |i| generateVersion( "FIX", 4, i, 0, 0, aggregator ) }
+(0..2).each { |i| generateVersion( "FIX", 5, 0, i, i + 7, aggregator ) }
\ No newline at end of file
