@@ -1,3 +1,6 @@
+#!/bin/bash
+set -e
+
 xsltproc -o ../src/.NET/FIX40_MessageCracker.cs net_MessageCracker.xsl FIX40.xml
 xsltproc -o ../src/.NET/FIX41_MessageCracker.cs net_MessageCracker.xsl FIX41.xml
 xsltproc -o ../src/.NET/FIX42_MessageCracker.cs net_MessageCracker.xsl FIX42.xml
@@ -17,3 +20,4 @@ xsltproc -o ../src/.NET/FIX50_MessageFactory.cs net_MessageFactory.xsl FIX50.xml
 xsltproc -o ../src/.NET/FIX50SP1_MessageFactory.cs net_MessageFactory.xsl FIX50SP1.xml
 xsltproc -o ../src/.NET/FIX50SP2_MessageFactory.cs net_MessageFactory.xsl FIX50SP2.xml
 xsltproc -o ../src/.NET/FIXT11_MessageFactory.cs net_MessageFactory.xsl FIXT11.xml
+
