@@ -1,5 +1,5 @@
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -22,7 +22,6 @@
 #else
 #include "config.h"
 #endif
-#include "CallStack.h"
 
 #include "Session.h"
 #include "Values.h"
@@ -61,6 +60,7 @@ Session::Session( Application& application,
   m_refreshOnLogon( false ),
   m_millisecondsInTimeStamp( true ),
   m_persistMessages( true ),
+  m_validateLengthAndChecksum( true ),
   m_dataDictionaryProvider( dataDictionaryProvider ),
   m_messageStoreFactory( messageStoreFactory ),
   m_pLogFactory( pLogFactory ),
@@ -81,17 +81,15 @@ Session::Session( Application& application,
 }
 
 Session::~Session()
-{ QF_STACK_IGNORE_BEGIN
+{
   removeSession( *this );
   m_messageStoreFactory.destroy( m_state.store() );
   if ( m_pLogFactory && m_state.log() )
     m_pLogFactory->destroy( m_state.log() );
-  QF_STACK_IGNORE_END
 }
 
 void Session::insertSendingTime( Header& header )
-{ QF_STACK_PUSH(Session::insertSendingTime)
-
+{
   UtcTimeStamp now;
   bool showMilliseconds = false;
   if( m_sessionID.getBeginString() == BeginString_FIXT11 )
@@ -100,13 +98,10 @@ void Session::insertSendingTime( Header& header )
     showMilliseconds = m_sessionID.getBeginString() >= BeginString_FIX42;
 
   header.setField( SendingTime(now, showMilliseconds && m_millisecondsInTimeStamp) );
-
-  QF_STACK_POP
 }
 
 void Session::insertOrigSendingTime( Header& header, const UtcTimeStamp& when )
-{ QF_STACK_PUSH(Session::insertSendingTime)
-
+{
   bool showMilliseconds = false;
   if( m_sessionID.getBeginString() == BeginString_FIXT11 )
     showMilliseconds = true;
@@ -114,13 +109,10 @@ void Session::insertOrigSendingTime( Header& header, const UtcTimeStamp& when )
     showMilliseconds = m_sessionID.getBeginString() >= BeginString_FIX42;
 
   header.setField( OrigSendingTime(when, showMilliseconds && m_millisecondsInTimeStamp) );
-
-  QF_STACK_POP
 }
 
 void Session::fill( Header& header )
-{ QF_STACK_PUSH(Session::fill)
-
+{
   UtcTimeStamp now;
   m_state.lastSentTime( now );
   header.setField( m_sessionID.getBeginString() );
@@ -128,8 +120,6 @@ void Session::fill( Header& header )
   header.setField( m_sessionID.getTargetCompID() );
   header.setField( MsgSeqNum( getExpectedSenderNum() ) );
   insertSendingTime( header );
-
-  QF_STACK_POP
 }
 
 void Session::next()
@@ -138,8 +128,7 @@ void Session::next()
 }
 
 void Session::next( const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::next)
-
+{
   try
   {
     if ( !checkSessionTime(timeStamp) )
@@ -208,13 +197,10 @@ void Session::next( const UtcTimeStamp& timeStamp )
     m_state.onEvent( e.what() );
     disconnect();
   }
-
-  QF_STACK_POP
 }
 
 void Session::nextLogon( const Message& logon, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextLogon)
-
+{
   SenderCompID senderCompID;
   TargetCompID targetCompID;
   logon.getHeader().getField( senderCompID );
@@ -223,6 +209,13 @@ void Session::nextLogon( const Message& logon, const UtcTimeStamp& timeStamp )
   if( m_refreshOnLogon )
     refresh();
 
+  if( !isEnabled() )
+  {
+    m_state.onEvent( "Session is not enabled for logon" );
+    disconnect();
+    return;
+  }
+
   if( !isLogonTime(timeStamp) )
   {
     m_state.onEvent( "Received logon outside of valid logon time" );
@@ -231,8 +224,7 @@ void Session::nextLogon( const Message& logon, const UtcTimeStamp& timeStamp )
   }
 
   ResetSeqNumFlag resetSeqNumFlag(false);
-  if( logon.isSetField(resetSeqNumFlag) )
-    logon.getField( resetSeqNumFlag );
+  logon.getFieldIfSet(resetSeqNumFlag);
   m_state.receivedReset( resetSeqNumFlag );
 
   if( m_state.receivedReset() )
@@ -258,8 +250,7 @@ void Session::nextLogon( const Message& logon, const UtcTimeStamp& timeStamp )
   if ( !m_state.initiate() 
        || (m_state.receivedReset() && !m_state.sentReset()) )
   {
-    if( logon.isSetField(m_state.heartBtInt()) )
-      logon.getField( m_state.heartBtInt() );
+    logon.getFieldIfSet(m_state.heartBtInt());
     m_state.onEvent( "Received logon request" );
     generateLogon( logon );
     m_state.onEvent( "Responding to logon request" );
@@ -284,34 +275,25 @@ void Session::nextLogon( const Message& logon, const UtcTimeStamp& timeStamp )
 
   if ( isLoggedOn() )
     m_application.onLogon( m_sessionID );
-
-  QF_STACK_POP
 }
 
 void Session::nextHeartbeat( const Message& heartbeat, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextHeartbeat)
-
+{
   if ( !verify( heartbeat ) ) return ;
   m_state.incrNextTargetMsgSeqNum();
   nextQueued( timeStamp );
-
-  QF_STACK_POP
 }
 
 void Session::nextTestRequest( const Message& testRequest, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextTestRequest)
-
+{
   if ( !verify( testRequest ) ) return ;
   generateHeartbeat( testRequest );
   m_state.incrNextTargetMsgSeqNum();
   nextQueued( timeStamp );
-
-  QF_STACK_POP
 }
 
 void Session::nextLogout( const Message& logout, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextLogout)
-
+{
   if ( !verify( logout, false, false ) ) return ;
   if ( !m_state.sentLogout() )
   {
@@ -325,38 +307,29 @@ void Session::nextLogout( const Message& logout, const UtcTimeStamp& timeStamp )
   m_state.incrNextTargetMsgSeqNum();
   if ( m_resetOnLogout ) m_state.reset();
   disconnect();
-
-  QF_STACK_POP
 }
 
 void Session::nextReject( const Message& reject, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextReject)
-
+{
   if ( !verify( reject, false, true ) ) return ;
   m_state.incrNextTargetMsgSeqNum();
   nextQueued( timeStamp );
-
-  QF_STACK_POP
 }
 
 void Session::nextSequenceReset( const Message& sequenceReset, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextSequenceReset)
-
+{
   bool isGapFill = false;
   GapFillFlag gapFillFlag;
-  if ( sequenceReset.isSetField( gapFillFlag ) )
+  if ( sequenceReset.getFieldIfSet( gapFillFlag ) )
   {
-    sequenceReset.getField( gapFillFlag );
     isGapFill = gapFillFlag;
   }
 
   if ( !verify( sequenceReset, isGapFill, isGapFill ) ) return ;
 
   NewSeqNo newSeqNo;
-  if ( sequenceReset.isSetField( newSeqNo ) )
+  if ( sequenceReset.getFieldIfSet( newSeqNo ) )
   {
-    sequenceReset.getField( newSeqNo );
-
     m_state.onEvent( "Received SequenceReset FROM: "
                      + IntConvertor::convert( getExpectedTargetNum() ) +
                      " TO: " + IntConvertor::convert( newSeqNo ) );
@@ -366,13 +339,10 @@ void Session::nextSequenceReset( const Message& sequenceReset, const UtcTimeStam
     else if ( newSeqNo < getExpectedTargetNum() )
       generateReject( sequenceReset, SessionRejectReason_VALUE_IS_INCORRECT );
   }
-
-  QF_STACK_POP
 }
 
 void Session::nextResendRequest( const Message& resendRequest, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextResendRequest)
-
+{
   if ( !verify( resendRequest, false, false ) ) return ;
 
   Locker l( m_mutex );
@@ -422,18 +392,16 @@ void Session::nextResendRequest( const Message& resendRequest, const UtcTimeStam
     {
       msg.setStringHeader(*i);
       ApplVerID applVerID;
-      if( msg.getHeader().isSetField(applVerID) )
-        msg.getHeader().getField(applVerID);
-      else
+      if( !msg.getHeader().getFieldIfSet(applVerID) )
         applVerID = m_senderDefaultApplVerID;
 
       const DataDictionary& applicationDD =
         m_dataDictionaryProvider.getApplicationDataDictionary(applVerID);
-      msg = Message( *i, sessionDD, applicationDD );
+      msg = Message( *i, sessionDD, applicationDD, m_validateLengthAndChecksum );
     }
     else
     {
-      msg = Message( *i, sessionDD );
+      msg = Message( *i, sessionDD, m_validateLengthAndChecksum );
     }
 
 
@@ -479,23 +447,17 @@ void Session::nextResendRequest( const Message& resendRequest, const UtcTimeStam
   resendRequest.getHeader().getField( msgSeqNum );
   if( !isTargetTooHigh(msgSeqNum) && !isTargetTooLow(msgSeqNum) )
     m_state.incrNextTargetMsgSeqNum();
-
-  QF_STACK_POP
 }
 
 bool Session::send( Message& message )
-{ QF_STACK_PUSH(Session::send)
-
+{
   message.getHeader().removeField( FIELD::PossDupFlag );
   message.getHeader().removeField( FIELD::OrigSendingTime );
   return sendRaw( message );
-
-  QF_STACK_POP
 }
 
 bool Session::sendRaw( Message& message, int num )
-{ QF_STACK_PUSH(Session::sendRaw)
-
+{
   Locker l( m_mutex );
 
   try
@@ -503,8 +465,7 @@ bool Session::sendRaw( Message& message, int num )
     Header& header = message.getHeader();
 
     MsgType msgType;
-    if( header.isSetField(msgType) )
-      header.getField( msgType );
+    header.getFieldIfSet(msgType);
 
     fill( header );
     std::string messageString;
@@ -519,8 +480,8 @@ bool Session::sendRaw( Message& message, int num )
       if( msgType == "A" && !m_state.receivedReset() )
       {
         ResetSeqNumFlag resetSeqNumFlag( false );
-        if( message.isSetField(resetSeqNumFlag) )
-          message.getField( resetSeqNumFlag );
+        message.getFieldIfSet(resetSeqNumFlag);
+
         if( resetSeqNumFlag )
         {
           m_state.reset();
@@ -569,23 +530,17 @@ bool Session::sendRaw( Message& message, int num )
     m_state.onEvent( e.what() );
     return false;
   }
-
-  QF_STACK_POP
 }
 
 bool Session::send( const std::string& string )
-{ QF_STACK_PUSH(Session::send)
-
+{
   if ( !m_pResponder ) return false;
   m_state.onOutgoing( string );
   return m_pResponder->send( string );
-
-  QF_STACK_POP
 }
 
 void Session::disconnect()
-{ QF_STACK_PUSH(Session::disconnect)
-
+{
   Locker l(m_mutex);
 
   if ( m_pResponder )
@@ -612,13 +567,10 @@ void Session::disconnect()
     m_state.reset();
 
   m_state.resendRange( 0, 0 );
-
-  QF_STACK_POP
 }
 
 bool Session::resend( Message& message )
-{ QF_STACK_PUSH(Session::resend)
-
+{
   SendingTime sendingTime;
   MsgSeqNum msgSeqNum;
   Header& header = message.getHeader();
@@ -635,8 +587,6 @@ bool Session::resend( Message& message )
   }
   catch ( DoNotSend& )
   { return false; }
-
-  QF_STACK_POP
 }
 
 void Session::persist( const Message& message,  const std::string& messageString ) 
@@ -650,8 +600,7 @@ throw ( IOException )
 }
 
 void Session::generateLogon()
-{ QF_STACK_PUSH(Session::generateLogon)
-
+{
   Message logon;
   logon.getHeader().setField( MsgType( "A" ) );
   logon.setField( EncryptMethod( 0 ) );
@@ -671,13 +620,10 @@ void Session::generateLogon()
   m_state.testRequest( 0 );
   m_state.sentLogon( true );
   sendRaw( logon );
-
-  QF_STACK_POP
 }
 
 void Session::generateLogon( const Message& aLogon )
-{ QF_STACK_PUSH(Session::generateLogon)
-
+{
   Message logon;
   EncryptMethod encryptMethod;
   HeartBtInt heartBtInt;
@@ -692,13 +638,10 @@ void Session::generateLogon( const Message& aLogon )
   fill( logon.getHeader() );
   sendRaw( logon );
   m_state.sentLogon( true );
-
-  QF_STACK_POP
 }
 
 void Session::generateResendRequest( const BeginString& beginString, const MsgSeqNum& msgSeqNum )
-{ QF_STACK_PUSH(Session::generateResendRequest)
-
+{
   Message resendRequest;
   BeginSeqNo beginSeqNo( ( int ) getExpectedTargetNum() );
   EndSeqNo endSeqNo( msgSeqNum - 1 );
@@ -717,14 +660,11 @@ void Session::generateResendRequest( const BeginString& beginString, const MsgSe
                    " TO: " + IntConvertor::convert( endSeqNo ) );
 
   m_state.resendRange( beginSeqNo, msgSeqNum - 1 );
-
-  QF_STACK_POP
 }
 
 void Session::generateSequenceReset
 ( int beginSeqNo, int endSeqNo )
-{ QF_STACK_PUSH(Session::generateSequenceReset)
-
+{
   Message sequenceReset;
   NewSeqNo newSeqNo( endSeqNo );
   sequenceReset.getHeader().setField( MsgType( "4" ) );
@@ -740,24 +680,18 @@ void Session::generateSequenceReset
   sendRaw( sequenceReset, beginSeqNo );
   m_state.onEvent( "Sent SequenceReset TO: "
                    + IntConvertor::convert( newSeqNo ) );
-
-  QF_STACK_POP
 }
 
 void Session::generateHeartbeat()
-{ QF_STACK_PUSH(Session::generateHeartbeat)
-
+{
   Message heartbeat;
   heartbeat.getHeader().setField( MsgType( "0" ) );
   fill( heartbeat.getHeader() );
   sendRaw( heartbeat );
-
-  QF_STACK_POP
 }
 
 void Session::generateHeartbeat( const Message& testRequest )
-{ QF_STACK_PUSH(Session::generateHeartbeat)
-
+{
   Message heartbeat;
   heartbeat.getHeader().setField( MsgType( "0" ) );
   fill( heartbeat.getHeader() );
@@ -770,13 +704,10 @@ void Session::generateHeartbeat( const Message& testRequest )
   catch ( FieldNotFound& ) {}
 
   sendRaw( heartbeat );
-
-  QF_STACK_POP
 }
 
 void Session::generateTestRequest( const std::string& id )
-{ QF_STACK_PUSH(Session::generateTestRequest)
-
+{
   Message testRequest;
   testRequest.getHeader().setField( MsgType( "1" ) );
   fill( testRequest.getHeader() );
@@ -784,13 +715,10 @@ void Session::generateTestRequest( const std::string& id )
   testRequest.setField( testReqID );
 
   sendRaw( testRequest );
-
-  QF_STACK_POP
 }
 
 void Session::generateReject( const Message& message, int err, int field )
-{ QF_STACK_PUSH(Session::generateReject)
-
+{
   std::string beginString = m_sessionID.getBeginString();
 
   Message reject;
@@ -802,9 +730,8 @@ void Session::generateReject( const Message& message, int err, int field )
   MsgType msgType;
 
   message.getHeader().getField( msgType );
-  if( message.getHeader().isSetField( msgSeqNum ) )
+  if( message.getHeader().getFieldIfSet( msgSeqNum ) )
   {
-    message.getHeader().getField( msgSeqNum );
     if( msgSeqNum.getString() != "" )
       reject.setField( RefSeqNum( msgSeqNum ) );
   }
@@ -883,13 +810,10 @@ void Session::generateReject( const Message& message, int err, int field )
     throw std::runtime_error( "Tried to send a reject while not logged on" );
 
   sendRaw( reject );
-
-  QF_STACK_POP
 }
 
 void Session::generateReject( const Message& message, const std::string& str )
-{ QF_STACK_PUSH(Session::generateReject)
-
+{
   std::string beginString = m_sessionID.getBeginString();
 
   Message reject;
@@ -913,15 +837,14 @@ void Session::generateReject( const Message& message, const std::string& str )
   sendRaw( reject );
   m_state.onEvent( "Message " + msgSeqNum.getString()
                    + " Rejected: " + str );
-
-  QF_STACK_POP
 }
 
 void Session::generateBusinessReject( const Message& message, int err, int field )
-{ QF_STACK_PUSH(Session::generateBusinessReject)
-
+{
   Message reject;
   reject.getHeader().setField( MsgType( MsgType_BusinessMessageReject ) );
+  if( m_sessionID.isFIXT() )
+    reject.setField( DefaultApplVerID(m_senderDefaultApplVerID) );  
   fill( reject.getHeader() );
   MsgType msgType;
   MsgSeqNum msgSeqNum;
@@ -977,13 +900,10 @@ void Session::generateBusinessReject( const Message& message, int err, int field
     m_state.onEvent( "Message " + msgSeqNum.getString() + " Rejected" );
 
   sendRaw( reject );
-
-  QF_STACK_POP
 }
 
 void Session::generateLogout( const std::string& text )
-{ QF_STACK_PUSH(Session::generateLogout)
-
+{
   Message logout;
   logout.getHeader().setField( MsgType( MsgType_Logout ) );
   fill( logout.getHeader() );
@@ -991,14 +911,11 @@ void Session::generateLogout( const std::string& text )
     logout.setField( Text( text ) );
   sendRaw( logout );
   m_state.sentLogout( true );
-
-  QF_STACK_POP
 }
 
 void Session::populateRejectReason( Message& reject, int field,
                                     const std::string& text )
-{ QF_STACK_PUSH(Session::populateRejectReason)
-
+{
   MsgType msgType;
    reject.getHeader().getField( msgType );
 
@@ -1014,20 +931,16 @@ void Session::populateRejectReason( Message& reject, int field,
     stream << text << " (" << field << ")";
     reject.setField( Text( stream.str() ) );
   }
-
-  QF_STACK_POP
 }
 
 void Session::populateRejectReason( Message& reject, const std::string& text )
-{ QF_STACK_PUSH(Session::populateRejectReason)
+{
   reject.setField( Text( text ) );
-  QF_STACK_POP
 }
 
 bool Session::verify( const Message& msg, bool checkTooHigh,
                       bool checkTooLow )
-{ QF_STACK_PUSH(Session::verify)
-
+{
   const MsgType* pMsgType = 0;
   const MsgSeqNum* pMsgSeqNum = 0;
 
@@ -1095,13 +1008,10 @@ bool Session::verify( const Message& msg, bool checkTooHigh,
 
   fromCallback( pMsgType ? *pMsgType : MsgType(), msg, m_sessionID );
   return true;
-
-  QF_STACK_POP
 }
 
 bool Session::shouldSendReset()
-{ QF_STACK_PUSH(Session::shouldSendReset)
-
+{
   std::string beginString = m_sessionID.getBeginString();
   return beginString >= FIX::BeginString_FIX41
     && ( m_resetOnLogon || 
@@ -1109,13 +1019,10 @@ bool Session::shouldSendReset()
          m_resetOnDisconnect )
     && ( getExpectedSenderNum() == 1 )
     && ( getExpectedTargetNum() == 1 );
-
-  QF_STACK_POP
 }
 
 bool Session::validLogonState( const MsgType& msgType )
-{ QF_STACK_PUSH(Session::validLogonState)
-
+{
   if ( (msgType == MsgType_Logon && m_state.sentReset()) 
        || (m_state.receivedReset()) )
     return true;
@@ -1132,43 +1039,31 @@ bool Session::validLogonState( const MsgType& msgType )
     return true;
 
   return false;
-
-  QF_STACK_POP
 }
 
 void Session::fromCallback( const MsgType& msgType, const Message& msg,
                             const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::fromCallback)
-
+{
   if ( Message::isAdminMsgType( msgType ) )
     m_application.fromAdmin( msg, m_sessionID );
   else
     m_application.fromApp( msg, m_sessionID );
-
-  QF_STACK_POP
 }
 
 void Session::doBadTime( const Message& msg )
-{ QF_STACK_PUSH(Session::doBadTime)
-
+{
   generateReject( msg, SessionRejectReason_SENDINGTIME_ACCURACY_PROBLEM );
   generateLogout();
-
-  QF_STACK_POP
 }
 
 void Session::doBadCompID( const Message& msg )
-{ QF_STACK_PUSH(Session::doBadCompID)
-
+{
   generateReject( msg, SessionRejectReason_COMPID_PROBLEM );
   generateLogout();
-
-  QF_STACK_POP
 }
 
 bool Session::doPossDup( const Message& msg )
-{ QF_STACK_PUSH(Session::doPossDup)
-
+{
   const Header & header = msg.getHeader();
   OrigSendingTime origSendingTime;
   SendingTime sendingTime;
@@ -1179,12 +1074,11 @@ bool Session::doPossDup( const Message& msg )
 
   if ( msgType != MsgType_SequenceReset )
   {
-    if ( !header.isSetField( origSendingTime ) )
+    if ( !header.getFieldIfSet( origSendingTime ) )
     {
       generateReject( msg, SessionRejectReason_REQUIRED_TAG_MISSING, origSendingTime.getField() );
       return false;
     }
-    header.getField( origSendingTime );
 
     if ( origSendingTime > sendingTime )
     {
@@ -1194,18 +1088,14 @@ bool Session::doPossDup( const Message& msg )
     }
   }
   return true;
-
-  QF_STACK_POP
 }
 
 bool Session::doTargetTooLow( const Message& msg )
-{ QF_STACK_PUSH(Session::doTargetTooLow)
-
+{
   const Header & header = msg.getHeader();
   PossDupFlag possDupFlag(false);
   MsgSeqNum msgSeqNum;
-  if( header.isSetField(possDupFlag) )
-    header.getField( possDupFlag );
+  header.getFieldIfSet(possDupFlag);
   header.getField( msgSeqNum );
 
   if ( !possDupFlag )
@@ -1218,13 +1108,10 @@ bool Session::doTargetTooLow( const Message& msg )
   }
 
   return doPossDup( msg );
-
-  QF_STACK_POP
 }
 
 void Session::doTargetTooHigh( const Message& msg )
-{ QF_STACK_PUSH(Session::doTargetTooHigh)
-
+{
   const Header & header = msg.getHeader();
   BeginString beginString;
   MsgSeqNum msgSeqNum;
@@ -1253,19 +1140,15 @@ void Session::doTargetTooHigh( const Message& msg )
   }
 
   generateResendRequest( beginString, msgSeqNum );
-
-  QF_STACK_POP
 }
 
 void Session::nextQueued( const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextQueued)
+{
   while ( nextQueued( getExpectedTargetNum(), timeStamp ) ) {}
-  QF_STACK_POP
 }
 
 bool Session::nextQueued( int num, const UtcTimeStamp& timeStamp )
-{ QF_STACK_PUSH(Session::nextQueued)
-
+{
   Message msg;
   MsgType msgType;
 
@@ -1286,13 +1169,10 @@ bool Session::nextQueued( int num, const UtcTimeStamp& timeStamp )
     return true;
   }
   return false;
-
-  QF_STACK_POP
 }
 
 void Session::next( const std::string& msg, const UtcTimeStamp& timeStamp, bool queued )
-{ QF_STACK_PUSH(Session::next)
-
+{
   try
   {
     m_state.onIncoming( msg );
@@ -1302,11 +1182,11 @@ void Session::next( const std::string& msg, const UtcTimeStamp& timeStamp, bool
     {
       const DataDictionary& applicationDD =
         m_dataDictionaryProvider.getApplicationDataDictionary(m_senderDefaultApplVerID);
-      next( Message( msg, sessionDD, applicationDD ), timeStamp, queued );
+      next( Message( msg, sessionDD, applicationDD, m_validateLengthAndChecksum ), timeStamp, queued );
     }
     else
     {
-      next( Message( msg, sessionDD ), timeStamp, queued );
+      next( Message( msg, sessionDD, m_validateLengthAndChecksum ), timeStamp, queued );
     }
   }
   catch( InvalidMessage& e )
@@ -1323,13 +1203,10 @@ void Session::next( const std::string& msg, const UtcTimeStamp& timeStamp, bool
     } catch( MessageParseError& ) {}
     throw e;
   }
-
-  QF_STACK_POP
 }
 
 void Session::next( const Message& message, const UtcTimeStamp& timeStamp, bool queued )
-{ QF_STACK_PUSH(Session::next)
-
+{
   const Header& header = message.getHeader();
 
   try
@@ -1339,8 +1216,9 @@ void Session::next( const Message& message, const UtcTimeStamp& timeStamp, bool
 
     const MsgType& msgType = FIELD_GET_REF( header, MsgType );
     const BeginString& beginString = FIELD_GET_REF( header, BeginString );
-    FIELD_GET_REF( header, SenderCompID );
-    FIELD_GET_REF( header, TargetCompID );
+    // make sure these fields are present
+    FIELD_THROW_IF_NOT_FOUND( header, SenderCompID );
+    FIELD_THROW_IF_NOT_FOUND( header, TargetCompID );
 
     if ( beginString != m_sessionID.getBeginString() )
       throw UnsupportedVersion();
@@ -1364,8 +1242,7 @@ void Session::next( const Message& message, const UtcTimeStamp& timeStamp, bool
     if( m_sessionID.isFIXT() && message.isApp() )
     {
       ApplVerID applVerID = m_targetDefaultApplVerID;
-      if( header.isSetField(FIELD::ApplVerID) )
-        header.getField(applVerID);
+      header.getFieldIfSet(applVerID);
       const DataDictionary& applicationDataDictionary = 
         m_dataDictionaryProvider.getApplicationDataDictionary(applVerID);
       DataDictionary::validate( message, &sessionDataDictionary, &applicationDataDictionary );
@@ -1469,34 +1346,26 @@ void Session::next( const Message& message, const UtcTimeStamp& timeStamp, bool
 
   if( isLoggedOn() )
     next();
-
-  QF_STACK_POP
 }
 
 bool Session::sendToTarget( Message& message, const std::string& qualifier )
 throw( SessionNotFound )
-{ QF_STACK_PUSH(Session::sendToTarget)
-
+{
   try
   {
     SessionID sessionID = message.getSessionID( qualifier );
     return sendToTarget( message, sessionID );
   }
   catch ( FieldNotFound& ) { throw SessionNotFound(); }
-
-  QF_STACK_POP
 }
 
 bool Session::sendToTarget( Message& message, const SessionID& sessionID )
 throw( SessionNotFound )
-{ QF_STACK_PUSH(Session::sendToTarget)
-
+{
   message.setSessionID( sessionID );
   Session* pSession = lookupSession( sessionID );
   if ( !pSession ) throw SessionNotFound();
   return pSession->send( message );
-
-  QF_STACK_POP
 }
 
 bool Session::sendToTarget
@@ -1505,25 +1374,19 @@ bool Session::sendToTarget
   const TargetCompID& targetCompID,
   const std::string& qualifier )
 throw( SessionNotFound )
-{ QF_STACK_PUSH(Session::sendToTarget)
-
+{
   message.getHeader().setField( senderCompID );
   message.getHeader().setField( targetCompID );
   return sendToTarget( message, qualifier );
-
-  QF_STACK_POP
 }
 
 bool Session::sendToTarget
 ( Message& message, const std::string& sender, const std::string& target,
   const std::string& qualifier )
 throw( SessionNotFound )
-{ QF_STACK_PUSH(Session::sendToTarget)
-
+{
   return sendToTarget( message, SenderCompID( sender ),
                        TargetCompID( target ), qualifier );
-
-  QF_STACK_POP
 }
 
 std::set<SessionID> Session::getSessions()
@@ -1532,30 +1395,23 @@ std::set<SessionID> Session::getSessions()
 }
 
 bool Session::doesSessionExist( const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::doesSessionExist)
-
+{
   Locker locker( s_mutex );
   return s_sessions.end() != s_sessions.find( sessionID );
-
-  QF_STACK_POP
 }
 
 Session* Session::lookupSession( const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::lookupSession)
-
+{
   Locker locker( s_mutex );
   Sessions::iterator find = s_sessions.find( sessionID );
   if ( find != s_sessions.end() )
     return find->second;
   else
     return 0;
-
-  QF_STACK_POP
 }
 
 Session* Session::lookupSession( const std::string& string, bool reverse )
-{ QF_STACK_PUSH(Session::lookupSession)
-
+{
   Message message;
   if ( !message.setStringHeader( string ) )
     return 0;
@@ -1577,49 +1433,38 @@ Session* Session::lookupSession( const std::string& string, bool reverse )
                           targetCompID ) );
   }
   catch ( FieldNotFound& ) { return 0; }
-
-  QF_STACK_POP
 }
 
 bool Session::isSessionRegistered( const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::isSessionRegistered)
-
+{
   Locker locker( s_mutex );
   return s_registered.end() != s_registered.find( sessionID );
-
-  QF_STACK_POP
 }
 
 Session* Session::registerSession( const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::registerSession)
-
+{
   Locker locker( s_mutex );
   Session* pSession = lookupSession( sessionID );
   if ( pSession == 0 ) return 0;
   if ( isSessionRegistered( sessionID ) ) return 0;
   s_registered[ sessionID ] = pSession;
   return pSession;
-
-  QF_STACK_POP
 }
 
 void Session::unregisterSession( const SessionID& sessionID )
-{ QF_STACK_PUSH(Session::unregisterSession)
+{
   Locker locker( s_mutex );
   s_registered.erase( sessionID );
-  QF_STACK_POP
 }
 
-int Session::numSessions()
-{ QF_STACK_PUSH(Session::numSessions)
+size_t Session::numSessions()
+{
   Locker locker( s_mutex );
   return s_sessions.size();
-  QF_STACK_POP
 }
 
 bool Session::addSession( Session& s )
-{ QF_STACK_PUSH(Session::addSession)
-
+{
   Locker locker( s_mutex );
   Sessions::iterator it = s_sessions.find( s.m_sessionID );
   if ( it == s_sessions.end() )
@@ -1630,18 +1475,13 @@ bool Session::addSession( Session& s )
   }
   else
     return false;
-
-  QF_STACK_POP
 }
 
 void Session::removeSession( Session& s )
-{ QF_STACK_PUSH(Session::removeSession)
-
+{
   Locker locker( s_mutex );
   s_sessions.erase( s.m_sessionID );
   s_sessionIDs.erase( s.m_sessionID );
   s_registered.erase( s.m_sessionID );
-
-  QF_STACK_POP
 }
 }
