@@ -1,7 +1,7 @@
 /* -*- C++ -*- */
  
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -22,8 +22,10 @@
 #ifndef FIX44_MESSAGECRACKER_H
 #define FIX44_MESSAGECRACKER_H
 
+
 #include "../SessionID.h"
 #include "../Exceptions.h"
+
 #include "../fix44/Message.h"
 
 namespace FIX44
@@ -74,6 +76,7 @@ namespace FIX44
   class BidRequest; 
   class BidResponse; 
   class ListStrikePrice; 
+  class XMLnonFIX; 
   class RegistrationInstructions; 
   class RegistrationInstructionsResponse; 
   class OrderMassCancelRequest; 
@@ -221,6 +224,8 @@ namespace FIX44
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const ListStrikePrice&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
+  virtual void onMessage( const XMLnonFIX&, const FIX::SessionID& ) 
+    {}
   virtual void onMessage( const RegistrationInstructions&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const RegistrationInstructionsResponse&, const FIX::SessionID& ) 
@@ -359,6 +364,7 @@ namespace FIX44
  virtual void onMessage( BidRequest&, const FIX::SessionID& ) {} 
  virtual void onMessage( BidResponse&, const FIX::SessionID& ) {} 
  virtual void onMessage( ListStrikePrice&, const FIX::SessionID& ) {} 
+ virtual void onMessage( XMLnonFIX&, const FIX::SessionID& ) {} 
  virtual void onMessage( RegistrationInstructions&, const FIX::SessionID& ) {} 
  virtual void onMessage( RegistrationInstructionsResponse&, const FIX::SessionID& ) {} 
  virtual void onMessage( OrderMassCancelRequest&, const FIX::SessionID& ) {} 
@@ -551,6 +557,9 @@ public:
     if( msgTypeValue == "m" )
       onMessage( (const ListStrikePrice&)message, sessionID );
     else
+    if( msgTypeValue == "n" )
+      onMessage( (const XMLnonFIX&)message, sessionID );
+    else
     if( msgTypeValue == "o" )
       onMessage( (const RegistrationInstructions&)message, sessionID );
     else
@@ -836,6 +845,9 @@ void crack( Message& message,
     if( msgTypeValue == "m" )
       onMessage( (ListStrikePrice&)message, sessionID );
     else
+    if( msgTypeValue == "n" )
+      onMessage( (XMLnonFIX&)message, sessionID );
+    else
     if( msgTypeValue == "o" )
       onMessage( (RegistrationInstructions&)message, sessionID );
     else
@@ -979,4 +991,4 @@ void crack( Message& message,
   };
 }
 
-#endif //FIX44_MESSAGECRACKER_H
+#endif
