@@ -44,6 +44,7 @@ namespace FIX50
     FIELD_SET(*this, FIX::QuoteRespID);
     FIELD_SET(*this, FIX::OrdStatusReqID);
     FIELD_SET(*this, FIX::MassStatusReqID);
+    FIELD_SET(*this, FIX::HostCrossID);
     FIELD_SET(*this, FIX::TotNumReports);
     FIELD_SET(*this, FIX::LastRptRequested);
     FIELD_SET(*this, FIX::NoPartyIDs);
@@ -94,6 +95,8 @@ namespace FIX50
     FIELD_SET(*this, FIX::PreallocMethod);
     FIELD_SET(*this, FIX::SettlType);
     FIELD_SET(*this, FIX::SettlDate);
+    FIELD_SET(*this, FIX::MatchType);
+    FIELD_SET(*this, FIX::OrderCategory);
     FIELD_SET(*this, FIX::CashMargin);
     FIELD_SET(*this, FIX::ClearingFeeIndicator);
     FIELD_SET(*this, FIX::Symbol);
@@ -106,6 +109,11 @@ namespace FIX50
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::PutOrCall);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -120,10 +128,17 @@ namespace FIX50
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
+    FIELD_SET(*this, FIX::StrikeMultiplier);
+    FIELD_SET(*this, FIX::StrikeValue);
     FIELD_SET(*this, FIX::OptAttribute);
     FIELD_SET(*this, FIX::ContractMultiplier);
+    FIELD_SET(*this, FIX::MinPriceIncrement);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
+    FIELD_SET(*this, FIX::TimeUnit);
     FIELD_SET(*this, FIX::CouponRate);
     FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
     FIELD_SET(*this, FIX::Issuer);
     FIELD_SET(*this, FIX::EncodedIssuerLen);
     FIELD_SET(*this, FIX::EncodedIssuer);
@@ -136,17 +151,6 @@ namespace FIX50
     FIELD_SET(*this, FIX::CPRegType);
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-    FIELD_SET(*this, FIX::StrikeMultiplier);
-    FIELD_SET(*this, FIX::StrikeValue);
-    FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
     FIELD_SET(*this, FIX::AgreementDesc);
     FIELD_SET(*this, FIX::AgreementID);
     FIELD_SET(*this, FIX::AgreementDate);
@@ -160,7 +164,7 @@ namespace FIX50
     class NoUnderlyings: public FIX::Group
     {
     public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,0)) {}
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,315,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1000,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,0)) {}
       FIELD_SET(*this, FIX::UnderlyingSymbol);
       FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
       FIELD_SET(*this, FIX::UnderlyingSecurityID);
@@ -171,6 +175,7 @@ namespace FIX50
       FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
       FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
       FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
       FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
       FIELD_SET(*this, FIX::UnderlyingIssueDate);
       FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -187,6 +192,8 @@ namespace FIX50
       FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
       FIELD_SET(*this, FIX::UnderlyingOptAttribute);
       FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
       FIELD_SET(*this, FIX::UnderlyingCouponRate);
       FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
       FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -197,25 +204,23 @@ namespace FIX50
       FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
       FIELD_SET(*this, FIX::UnderlyingCPProgram);
       FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
       FIELD_SET(*this, FIX::UnderlyingCurrency);
       FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
       FIELD_SET(*this, FIX::UnderlyingPx);
       FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
       FIELD_SET(*this, FIX::UnderlyingEndPrice);
       FIELD_SET(*this, FIX::UnderlyingStartValue);
       FIELD_SET(*this, FIX::UnderlyingCurrentValue);
       FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
       FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
       FIELD_SET(*this, FIX::UnderlyingFXRate);
       FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
     };
     FIELD_SET(*this, FIX::Side);
     FIELD_SET(*this, FIX::NoStipulations);
@@ -232,17 +237,34 @@ namespace FIX50
     FIELD_SET(*this, FIX::OrderPercent);
     FIELD_SET(*this, FIX::RoundingDirection);
     FIELD_SET(*this, FIX::RoundingModulus);
+    FIELD_SET(*this, FIX::LotType);
     FIELD_SET(*this, FIX::OrdType);
     FIELD_SET(*this, FIX::PriceType);
     FIELD_SET(*this, FIX::Price);
+    FIELD_SET(*this, FIX::PriceProtectionScope);
     FIELD_SET(*this, FIX::StopPx);
+    FIELD_SET(*this, FIX::TriggerType);
+    FIELD_SET(*this, FIX::TriggerAction);
+    FIELD_SET(*this, FIX::TriggerPrice);
+    FIELD_SET(*this, FIX::TriggerSymbol);
+    FIELD_SET(*this, FIX::TriggerSecurityID);
+    FIELD_SET(*this, FIX::TriggerSecurityIDSource);
+    FIELD_SET(*this, FIX::TriggerSecurityDesc);
+    FIELD_SET(*this, FIX::TriggerPriceType);
+    FIELD_SET(*this, FIX::TriggerPriceTypeScope);
+    FIELD_SET(*this, FIX::TriggerPriceDirection);
+    FIELD_SET(*this, FIX::TriggerNewPrice);
+    FIELD_SET(*this, FIX::TriggerOrderType);
+    FIELD_SET(*this, FIX::TriggerNewQty);
+    FIELD_SET(*this, FIX::TriggerTradingSessionID);
+    FIELD_SET(*this, FIX::TriggerTradingSessionSubID);
     FIELD_SET(*this, FIX::PegOffsetValue);
+    FIELD_SET(*this, FIX::PegPriceType);
     FIELD_SET(*this, FIX::PegMoveType);
     FIELD_SET(*this, FIX::PegOffsetType);
     FIELD_SET(*this, FIX::PegLimitType);
     FIELD_SET(*this, FIX::PegRoundDirection);
     FIELD_SET(*this, FIX::PegScope);
-    FIELD_SET(*this, FIX::PegPriceType);
     FIELD_SET(*this, FIX::PegSecurityIDSource);
     FIELD_SET(*this, FIX::PegSecurityID);
     FIELD_SET(*this, FIX::PegSymbol);
@@ -255,8 +277,18 @@ namespace FIX50
     FIELD_SET(*this, FIX::DiscretionRoundDirection);
     FIELD_SET(*this, FIX::DiscretionScope);
     FIELD_SET(*this, FIX::PeggedPrice);
+    FIELD_SET(*this, FIX::PeggedRefPrice);
     FIELD_SET(*this, FIX::DiscretionPrice);
     FIELD_SET(*this, FIX::TargetStrategy);
+    FIELD_SET(*this, FIX::NoStrategyParameters);
+    class NoStrategyParameters: public FIX::Group
+    {
+    public:
+    NoStrategyParameters() : FIX::Group(957,958,FIX::message_order(958,959,960,0)) {}
+      FIELD_SET(*this, FIX::StrategyParameterName);
+      FIELD_SET(*this, FIX::StrategyParameterType);
+      FIELD_SET(*this, FIX::StrategyParameterValue);
+    };
     FIELD_SET(*this, FIX::TargetStrategyParameters);
     FIELD_SET(*this, FIX::ParticipationRate);
     FIELD_SET(*this, FIX::TargetStrategyPerformance);
@@ -268,10 +300,14 @@ namespace FIX50
     FIELD_SET(*this, FIX::ExpireDate);
     FIELD_SET(*this, FIX::ExpireTime);
     FIELD_SET(*this, FIX::ExecInst);
+    FIELD_SET(*this, FIX::AggressorIndicator);
     FIELD_SET(*this, FIX::OrderCapacity);
     FIELD_SET(*this, FIX::OrderRestrictions);
+    FIELD_SET(*this, FIX::PreTradeAnonymity);
     FIELD_SET(*this, FIX::CustOrderCapacity);
     FIELD_SET(*this, FIX::LastQty);
+    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
+    FIELD_SET(*this, FIX::LastSwapPoints);
     FIELD_SET(*this, FIX::UnderlyingLastQty);
     FIELD_SET(*this, FIX::LastPx);
     FIELD_SET(*this, FIX::UnderlyingLastPx);
@@ -332,6 +368,16 @@ namespace FIX50
     FIELD_SET(*this, FIX::SettlCurrFxRateCalc);
     FIELD_SET(*this, FIX::HandlInst);
     FIELD_SET(*this, FIX::MinQty);
+    FIELD_SET(*this, FIX::MatchIncrement);
+    FIELD_SET(*this, FIX::MaxPriceLevels);
+    FIELD_SET(*this, FIX::DisplayQty);
+    FIELD_SET(*this, FIX::SecondaryDisplayQty);
+    FIELD_SET(*this, FIX::DisplayWhen);
+    FIELD_SET(*this, FIX::DisplayMethod);
+    FIELD_SET(*this, FIX::DisplayLowQty);
+    FIELD_SET(*this, FIX::DisplayHighQty);
+    FIELD_SET(*this, FIX::DisplayMinIncr);
+    FIELD_SET(*this, FIX::RefreshQty);
     FIELD_SET(*this, FIX::MaxFloor);
     FIELD_SET(*this, FIX::PositionEffect);
     FIELD_SET(*this, FIX::MaxShow);
@@ -367,7 +413,7 @@ namespace FIX50
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,687,690,683,564,565,539,654,566,587,588,637,685,675,1073,1074,1075,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1001,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1017,687,685,690,683,564,565,539,654,566,587,588,637,675,1073,1074,1075,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
@@ -394,6 +440,8 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegTimeUnit);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -409,9 +457,9 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegQty);
+      FIELD_SET(*this, FIX::LegOrderQty);
       FIELD_SET(*this, FIX::LegSwapType);
       FIELD_SET(*this, FIX::NoLegStipulations);
       class NoLegStipulations: public FIX::Group
@@ -445,7 +493,6 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegSettlType);
       FIELD_SET(*this, FIX::LegSettlDate);
       FIELD_SET(*this, FIX::LegLastPx);
-      FIELD_SET(*this, FIX::LegOrderQty);
       FIELD_SET(*this, FIX::LegSettlCurrency);
       FIELD_SET(*this, FIX::LegLastForwardPoints);
       FIELD_SET(*this, FIX::LegCalculatedCcyLastQty);
@@ -462,16 +509,6 @@ namespace FIX50
       FIELD_SET(*this, FIX::MiscFeeType);
       FIELD_SET(*this, FIX::MiscFeeBasis);
     };
-    FIELD_SET(*this, FIX::NoStrategyParameters);
-    class NoStrategyParameters: public FIX::Group
-    {
-    public:
-    NoStrategyParameters() : FIX::Group(957,958,FIX::message_order(958,959,960,0)) {}
-      FIELD_SET(*this, FIX::StrategyParameterName);
-      FIELD_SET(*this, FIX::StrategyParameterType);
-      FIELD_SET(*this, FIX::StrategyParameterValue);
-    };
-    FIELD_SET(*this, FIX::HostCrossID);
     FIELD_SET(*this, FIX::ManualOrderIndicator);
     FIELD_SET(*this, FIX::CustDirectedOrder);
     FIELD_SET(*this, FIX::ReceivedDeptID);
@@ -489,40 +526,6 @@ namespace FIX50
       FIELD_SET(*this, FIX::DeskTypeSource);
       FIELD_SET(*this, FIX::DeskOrderHandlingInst);
     };
-    FIELD_SET(*this, FIX::AggressorIndicator);
-    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
-    FIELD_SET(*this, FIX::LastSwapPoints);
-    FIELD_SET(*this, FIX::MatchType);
-    FIELD_SET(*this, FIX::OrderCategory);
-    FIELD_SET(*this, FIX::LotType);
-    FIELD_SET(*this, FIX::PriceProtectionScope);
-    FIELD_SET(*this, FIX::TriggerType);
-    FIELD_SET(*this, FIX::TriggerAction);
-    FIELD_SET(*this, FIX::TriggerPrice);
-    FIELD_SET(*this, FIX::TriggerSymbol);
-    FIELD_SET(*this, FIX::TriggerSecurityID);
-    FIELD_SET(*this, FIX::TriggerSecurityIDSource);
-    FIELD_SET(*this, FIX::TriggerSecurityDesc);
-    FIELD_SET(*this, FIX::TriggerPriceType);
-    FIELD_SET(*this, FIX::TriggerPriceTypeScope);
-    FIELD_SET(*this, FIX::TriggerPriceDirection);
-    FIELD_SET(*this, FIX::TriggerNewPrice);
-    FIELD_SET(*this, FIX::TriggerOrderType);
-    FIELD_SET(*this, FIX::TriggerNewQty);
-    FIELD_SET(*this, FIX::TriggerTradingSessionID);
-    FIELD_SET(*this, FIX::TriggerTradingSessionSubID);
-    FIELD_SET(*this, FIX::PeggedRefPrice);
-    FIELD_SET(*this, FIX::PreTradeAnonymity);
-    FIELD_SET(*this, FIX::MatchIncrement);
-    FIELD_SET(*this, FIX::MaxPriceLevels);
-    FIELD_SET(*this, FIX::SecondaryDisplayQty);
-    FIELD_SET(*this, FIX::DisplayWhen);
-    FIELD_SET(*this, FIX::DisplayMethod);
-    FIELD_SET(*this, FIX::DisplayLowQty);
-    FIELD_SET(*this, FIX::DisplayHighQty);
-    FIELD_SET(*this, FIX::DisplayMinIncr);
-    FIELD_SET(*this, FIX::RefreshQty);
-    FIELD_SET(*this, FIX::DisplayQty);
   };
 
 }
