@@ -92,8 +92,19 @@ namespace FIX50
     FIELD_SET(*this, FIX::HandlInst);
     FIELD_SET(*this, FIX::ExecInst);
     FIELD_SET(*this, FIX::MinQty);
+    FIELD_SET(*this, FIX::MatchIncrement);
+    FIELD_SET(*this, FIX::MaxPriceLevels);
+    FIELD_SET(*this, FIX::DisplayQty);
+    FIELD_SET(*this, FIX::SecondaryDisplayQty);
+    FIELD_SET(*this, FIX::DisplayWhen);
+    FIELD_SET(*this, FIX::DisplayMethod);
+    FIELD_SET(*this, FIX::DisplayLowQty);
+    FIELD_SET(*this, FIX::DisplayHighQty);
+    FIELD_SET(*this, FIX::DisplayMinIncr);
+    FIELD_SET(*this, FIX::RefreshQty);
     FIELD_SET(*this, FIX::MaxFloor);
     FIELD_SET(*this, FIX::ExDestination);
+    FIELD_SET(*this, FIX::ExDestinationIDSource);
     FIELD_SET(*this, FIX::NoTradingSessions);
     class NoTradingSessions: public FIX::Group
     {
@@ -114,6 +125,11 @@ namespace FIX50
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::PutOrCall);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -128,10 +144,17 @@ namespace FIX50
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
+    FIELD_SET(*this, FIX::StrikeMultiplier);
+    FIELD_SET(*this, FIX::StrikeValue);
     FIELD_SET(*this, FIX::OptAttribute);
     FIELD_SET(*this, FIX::ContractMultiplier);
+    FIELD_SET(*this, FIX::MinPriceIncrement);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
+    FIELD_SET(*this, FIX::TimeUnit);
     FIELD_SET(*this, FIX::CouponRate);
     FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
     FIELD_SET(*this, FIX::Issuer);
     FIELD_SET(*this, FIX::EncodedIssuerLen);
     FIELD_SET(*this, FIX::EncodedIssuer);
@@ -144,22 +167,11 @@ namespace FIX50
     FIELD_SET(*this, FIX::CPRegType);
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-    FIELD_SET(*this, FIX::StrikeMultiplier);
-    FIELD_SET(*this, FIX::StrikeValue);
-    FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
     FIELD_SET(*this, FIX::NoUnderlyings);
     class NoUnderlyings: public FIX::Group
     {
     public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,0)) {}
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,315,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1000,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,0)) {}
       FIELD_SET(*this, FIX::UnderlyingSymbol);
       FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
       FIELD_SET(*this, FIX::UnderlyingSecurityID);
@@ -170,6 +182,7 @@ namespace FIX50
       FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
       FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
       FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
       FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
       FIELD_SET(*this, FIX::UnderlyingIssueDate);
       FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -186,6 +199,8 @@ namespace FIX50
       FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
       FIELD_SET(*this, FIX::UnderlyingOptAttribute);
       FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
       FIELD_SET(*this, FIX::UnderlyingCouponRate);
       FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
       FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -196,32 +211,31 @@ namespace FIX50
       FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
       FIELD_SET(*this, FIX::UnderlyingCPProgram);
       FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
       FIELD_SET(*this, FIX::UnderlyingCurrency);
       FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
       FIELD_SET(*this, FIX::UnderlyingPx);
       FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
       FIELD_SET(*this, FIX::UnderlyingEndPrice);
       FIELD_SET(*this, FIX::UnderlyingStartValue);
       FIELD_SET(*this, FIX::UnderlyingCurrentValue);
       FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
       FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
       FIELD_SET(*this, FIX::UnderlyingFXRate);
       FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
     };
     FIELD_SET(*this, FIX::PrevClosePx);
+    FIELD_SET(*this, FIX::SwapPoints);
     FIELD_SET(*this, FIX::NoLegs);
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,687,690,683,670,564,565,539,654,566,587,588,1017,685,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1001,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1017,687,690,683,670,564,565,539,654,566,587,588,685,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
@@ -248,6 +262,8 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegTimeUnit);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -263,8 +279,7 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegQty);
       FIELD_SET(*this, FIX::LegSwapType);
       FIELD_SET(*this, FIX::NoLegStipulations);
@@ -326,7 +341,6 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegPrice);
       FIELD_SET(*this, FIX::LegSettlType);
       FIELD_SET(*this, FIX::LegSettlDate);
-      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegOrderQty);
     };
     FIELD_SET(*this, FIX::LocateReqd);
@@ -340,80 +354,8 @@ namespace FIX50
     FIELD_SET(*this, FIX::OrdType);
     FIELD_SET(*this, FIX::PriceType);
     FIELD_SET(*this, FIX::Price);
-    FIELD_SET(*this, FIX::StopPx);
-    FIELD_SET(*this, FIX::Currency);
-    FIELD_SET(*this, FIX::ComplianceID);
-    FIELD_SET(*this, FIX::SolicitedFlag);
-    FIELD_SET(*this, FIX::IOIID);
-    FIELD_SET(*this, FIX::QuoteID);
-    FIELD_SET(*this, FIX::TimeInForce);
-    FIELD_SET(*this, FIX::EffectiveTime);
-    FIELD_SET(*this, FIX::ExpireDate);
-    FIELD_SET(*this, FIX::ExpireTime);
-    FIELD_SET(*this, FIX::GTBookingInst);
-    FIELD_SET(*this, FIX::Commission);
-    FIELD_SET(*this, FIX::CommType);
-    FIELD_SET(*this, FIX::CommCurrency);
-    FIELD_SET(*this, FIX::FundRenewWaiv);
-    FIELD_SET(*this, FIX::OrderCapacity);
-    FIELD_SET(*this, FIX::OrderRestrictions);
-    FIELD_SET(*this, FIX::CustOrderCapacity);
-    FIELD_SET(*this, FIX::ForexReq);
-    FIELD_SET(*this, FIX::SettlCurrency);
-    FIELD_SET(*this, FIX::BookingType);
-    FIELD_SET(*this, FIX::Text);
-    FIELD_SET(*this, FIX::EncodedTextLen);
-    FIELD_SET(*this, FIX::EncodedText);
-    FIELD_SET(*this, FIX::PositionEffect);
-    FIELD_SET(*this, FIX::CoveredOrUncovered);
-    FIELD_SET(*this, FIX::MaxShow);
-    FIELD_SET(*this, FIX::PegOffsetValue);
-    FIELD_SET(*this, FIX::PegMoveType);
-    FIELD_SET(*this, FIX::PegOffsetType);
-    FIELD_SET(*this, FIX::PegLimitType);
-    FIELD_SET(*this, FIX::PegRoundDirection);
-    FIELD_SET(*this, FIX::PegScope);
-    FIELD_SET(*this, FIX::PegPriceType);
-    FIELD_SET(*this, FIX::PegSecurityIDSource);
-    FIELD_SET(*this, FIX::PegSecurityID);
-    FIELD_SET(*this, FIX::PegSymbol);
-    FIELD_SET(*this, FIX::PegSecurityDesc);
-    FIELD_SET(*this, FIX::DiscretionInst);
-    FIELD_SET(*this, FIX::DiscretionOffsetValue);
-    FIELD_SET(*this, FIX::DiscretionMoveType);
-    FIELD_SET(*this, FIX::DiscretionOffsetType);
-    FIELD_SET(*this, FIX::DiscretionLimitType);
-    FIELD_SET(*this, FIX::DiscretionRoundDirection);
-    FIELD_SET(*this, FIX::DiscretionScope);
-    FIELD_SET(*this, FIX::TargetStrategy);
-    FIELD_SET(*this, FIX::TargetStrategyParameters);
-    FIELD_SET(*this, FIX::ParticipationRate);
-    FIELD_SET(*this, FIX::CancellationRights);
-    FIELD_SET(*this, FIX::MoneyLaunderingStatus);
-    FIELD_SET(*this, FIX::RegistID);
-    FIELD_SET(*this, FIX::Designation);
-    FIELD_SET(*this, FIX::MultiLegRptTypeReq);
-    FIELD_SET(*this, FIX::NoStrategyParameters);
-    class NoStrategyParameters: public FIX::Group
-    {
-    public:
-    NoStrategyParameters() : FIX::Group(957,958,FIX::message_order(958,959,960,0)) {}
-      FIELD_SET(*this, FIX::StrategyParameterName);
-      FIELD_SET(*this, FIX::StrategyParameterType);
-      FIELD_SET(*this, FIX::StrategyParameterValue);
-    };
-    FIELD_SET(*this, FIX::SwapPoints);
-    FIELD_SET(*this, FIX::MatchIncrement);
-    FIELD_SET(*this, FIX::MaxPriceLevels);
-    FIELD_SET(*this, FIX::SecondaryDisplayQty);
-    FIELD_SET(*this, FIX::DisplayWhen);
-    FIELD_SET(*this, FIX::DisplayMethod);
-    FIELD_SET(*this, FIX::DisplayLowQty);
-    FIELD_SET(*this, FIX::DisplayHighQty);
-    FIELD_SET(*this, FIX::DisplayMinIncr);
-    FIELD_SET(*this, FIX::RefreshQty);
-    FIELD_SET(*this, FIX::DisplayQty);
     FIELD_SET(*this, FIX::PriceProtectionScope);
+    FIELD_SET(*this, FIX::StopPx);
     FIELD_SET(*this, FIX::TriggerType);
     FIELD_SET(*this, FIX::TriggerAction);
     FIELD_SET(*this, FIX::TriggerPrice);
@@ -429,10 +371,70 @@ namespace FIX50
     FIELD_SET(*this, FIX::TriggerNewQty);
     FIELD_SET(*this, FIX::TriggerTradingSessionID);
     FIELD_SET(*this, FIX::TriggerTradingSessionSubID);
+    FIELD_SET(*this, FIX::Currency);
+    FIELD_SET(*this, FIX::ComplianceID);
+    FIELD_SET(*this, FIX::SolicitedFlag);
+    FIELD_SET(*this, FIX::IOIID);
+    FIELD_SET(*this, FIX::QuoteID);
     FIELD_SET(*this, FIX::RefOrderID);
     FIELD_SET(*this, FIX::RefOrderIDSource);
+    FIELD_SET(*this, FIX::TimeInForce);
+    FIELD_SET(*this, FIX::EffectiveTime);
+    FIELD_SET(*this, FIX::ExpireDate);
+    FIELD_SET(*this, FIX::ExpireTime);
+    FIELD_SET(*this, FIX::GTBookingInst);
+    FIELD_SET(*this, FIX::Commission);
+    FIELD_SET(*this, FIX::CommType);
+    FIELD_SET(*this, FIX::CommCurrency);
+    FIELD_SET(*this, FIX::FundRenewWaiv);
+    FIELD_SET(*this, FIX::OrderCapacity);
+    FIELD_SET(*this, FIX::OrderRestrictions);
     FIELD_SET(*this, FIX::PreTradeAnonymity);
-    FIELD_SET(*this, FIX::ExDestinationIDSource);
+    FIELD_SET(*this, FIX::CustOrderCapacity);
+    FIELD_SET(*this, FIX::ForexReq);
+    FIELD_SET(*this, FIX::SettlCurrency);
+    FIELD_SET(*this, FIX::BookingType);
+    FIELD_SET(*this, FIX::Text);
+    FIELD_SET(*this, FIX::EncodedTextLen);
+    FIELD_SET(*this, FIX::EncodedText);
+    FIELD_SET(*this, FIX::PositionEffect);
+    FIELD_SET(*this, FIX::CoveredOrUncovered);
+    FIELD_SET(*this, FIX::MaxShow);
+    FIELD_SET(*this, FIX::PegOffsetValue);
+    FIELD_SET(*this, FIX::PegPriceType);
+    FIELD_SET(*this, FIX::PegMoveType);
+    FIELD_SET(*this, FIX::PegOffsetType);
+    FIELD_SET(*this, FIX::PegLimitType);
+    FIELD_SET(*this, FIX::PegRoundDirection);
+    FIELD_SET(*this, FIX::PegScope);
+    FIELD_SET(*this, FIX::PegSecurityIDSource);
+    FIELD_SET(*this, FIX::PegSecurityID);
+    FIELD_SET(*this, FIX::PegSymbol);
+    FIELD_SET(*this, FIX::PegSecurityDesc);
+    FIELD_SET(*this, FIX::DiscretionInst);
+    FIELD_SET(*this, FIX::DiscretionOffsetValue);
+    FIELD_SET(*this, FIX::DiscretionMoveType);
+    FIELD_SET(*this, FIX::DiscretionOffsetType);
+    FIELD_SET(*this, FIX::DiscretionLimitType);
+    FIELD_SET(*this, FIX::DiscretionRoundDirection);
+    FIELD_SET(*this, FIX::DiscretionScope);
+    FIELD_SET(*this, FIX::TargetStrategy);
+    FIELD_SET(*this, FIX::NoStrategyParameters);
+    class NoStrategyParameters: public FIX::Group
+    {
+    public:
+    NoStrategyParameters() : FIX::Group(957,958,FIX::message_order(958,959,960,0)) {}
+      FIELD_SET(*this, FIX::StrategyParameterName);
+      FIELD_SET(*this, FIX::StrategyParameterType);
+      FIELD_SET(*this, FIX::StrategyParameterValue);
+    };
+    FIELD_SET(*this, FIX::TargetStrategyParameters);
+    FIELD_SET(*this, FIX::ParticipationRate);
+    FIELD_SET(*this, FIX::CancellationRights);
+    FIELD_SET(*this, FIX::MoneyLaunderingStatus);
+    FIELD_SET(*this, FIX::RegistID);
+    FIELD_SET(*this, FIX::Designation);
+    FIELD_SET(*this, FIX::MultiLegRptTypeReq);
   };
 
 }
