@@ -16,12 +16,38 @@ namespace FIX50
     static FIX::MsgType MsgType() { return FIX::MsgType("AR"); }
 
     FIELD_SET(*this, FIX::TradeReportID);
+    FIELD_SET(*this, FIX::TradeID);
+    FIELD_SET(*this, FIX::SecondaryTradeID);
+    FIELD_SET(*this, FIX::FirmTradeID);
+    FIELD_SET(*this, FIX::SecondaryFirmTradeID);
     FIELD_SET(*this, FIX::TradeReportTransType);
     FIELD_SET(*this, FIX::TradeReportType);
     FIELD_SET(*this, FIX::TrdType);
     FIELD_SET(*this, FIX::TrdSubType);
     FIELD_SET(*this, FIX::SecondaryTrdType);
+    FIELD_SET(*this, FIX::TradeHandlingInstr);
+    FIELD_SET(*this, FIX::OrigTradeHandlingInstr);
+    FIELD_SET(*this, FIX::OrigTradeDate);
+    FIELD_SET(*this, FIX::OrigTradeID);
+    FIELD_SET(*this, FIX::OrigSecondaryTradeID);
     FIELD_SET(*this, FIX::TransferReason);
+    FIELD_SET(*this, FIX::NoRootPartyIDs);
+    class NoRootPartyIDs: public FIX::Group
+    {
+    public:
+    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
+      FIELD_SET(*this, FIX::RootPartyID);
+      FIELD_SET(*this, FIX::RootPartyIDSource);
+      FIELD_SET(*this, FIX::RootPartyRole);
+      FIELD_SET(*this, FIX::NoRootPartySubIDs);
+      class NoRootPartySubIDs: public FIX::Group
+      {
+      public:
+      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
+        FIELD_SET(*this, FIX::RootPartySubID);
+        FIELD_SET(*this, FIX::RootPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::ExecType);
     FIELD_SET(*this, FIX::TradeReportRefID);
     FIELD_SET(*this, FIX::SecondaryTradeReportRefID);
@@ -33,6 +59,17 @@ namespace FIX50
     FIELD_SET(*this, FIX::TrdMatchID);
     FIELD_SET(*this, FIX::ExecID);
     FIELD_SET(*this, FIX::SecondaryExecID);
+    FIELD_SET(*this, FIX::OrdStatus);
+    FIELD_SET(*this, FIX::ExecRestatementReason);
+    FIELD_SET(*this, FIX::PreviouslyReported);
+    FIELD_SET(*this, FIX::PriceType);
+    FIELD_SET(*this, FIX::UnderlyingTradingSessionID);
+    FIELD_SET(*this, FIX::UnderlyingTradingSessionSubID);
+    FIELD_SET(*this, FIX::SettlSessID);
+    FIELD_SET(*this, FIX::SettlSessSubID);
+    FIELD_SET(*this, FIX::QtyType);
+    FIELD_SET(*this, FIX::LastQty);
+    FIELD_SET(*this, FIX::LastPx);
     FIELD_SET(*this, FIX::Symbol);
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
@@ -43,6 +80,11 @@ namespace FIX50
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::PutOrCall);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -57,10 +99,17 @@ namespace FIX50
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
+    FIELD_SET(*this, FIX::StrikeMultiplier);
+    FIELD_SET(*this, FIX::StrikeValue);
     FIELD_SET(*this, FIX::OptAttribute);
     FIELD_SET(*this, FIX::ContractMultiplier);
+    FIELD_SET(*this, FIX::MinPriceIncrement);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
+    FIELD_SET(*this, FIX::TimeUnit);
     FIELD_SET(*this, FIX::CouponRate);
     FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
     FIELD_SET(*this, FIX::Issuer);
     FIELD_SET(*this, FIX::EncodedIssuerLen);
     FIELD_SET(*this, FIX::EncodedIssuer);
@@ -73,40 +122,92 @@ namespace FIX50
     FIELD_SET(*this, FIX::CPRegType);
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-    FIELD_SET(*this, FIX::StrikeMultiplier);
-    FIELD_SET(*this, FIX::StrikeValue);
-    FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::LastParPx);
+    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
+    FIELD_SET(*this, FIX::LastSwapPoints);
+    FIELD_SET(*this, FIX::LastSpotRate);
+    FIELD_SET(*this, FIX::LastForwardPoints);
+    FIELD_SET(*this, FIX::LastMkt);
+    FIELD_SET(*this, FIX::TradeDate);
+    FIELD_SET(*this, FIX::ClearingBusinessDate);
+    FIELD_SET(*this, FIX::AvgPx);
+    FIELD_SET(*this, FIX::AvgPxIndicator);
+    FIELD_SET(*this, FIX::MultiLegReportingType);
+    FIELD_SET(*this, FIX::TradeLegRefID);
     FIELD_SET(*this, FIX::TransactTime);
-    FIELD_SET(*this, FIX::NoTrdRegTimestamps);
-    class NoTrdRegTimestamps: public FIX::Group
+    FIELD_SET(*this, FIX::SettlType);
+    FIELD_SET(*this, FIX::NoUnderlyings);
+    class NoUnderlyings: public FIX::Group
     {
     public:
-    NoTrdRegTimestamps() : FIX::Group(768,769,FIX::message_order(769,770,771,1033,1034,1035,0)) {}
-      FIELD_SET(*this, FIX::TrdRegTimestamp);
-      FIELD_SET(*this, FIX::TrdRegTimestampType);
-      FIELD_SET(*this, FIX::TrdRegTimestampOrigin);
-      FIELD_SET(*this, FIX::DeskType);
-      FIELD_SET(*this, FIX::DeskTypeSource);
-      FIELD_SET(*this, FIX::DeskOrderHandlingInst);
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,315,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1000,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingSymbol);
+      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
+      FIELD_SET(*this, FIX::UnderlyingSecurityID);
+      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+      FIELD_SET(*this, FIX::UnderlyingProduct);
+      FIELD_SET(*this, FIX::UnderlyingCFICode);
+      FIELD_SET(*this, FIX::UnderlyingSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
+      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
+      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
+      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
+      FIELD_SET(*this, FIX::UnderlyingIssueDate);
+      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
+      FIELD_SET(*this, FIX::UnderlyingFactor);
+      FIELD_SET(*this, FIX::UnderlyingCreditRating);
+      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
+      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
+      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
+      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
+      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
+      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+      FIELD_SET(*this, FIX::UnderlyingCouponRate);
+      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
+      FIELD_SET(*this, FIX::UnderlyingIssuer);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
+      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::UnderlyingCPProgram);
+      FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
+      FIELD_SET(*this, FIX::UnderlyingCurrency);
+      FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
+      FIELD_SET(*this, FIX::UnderlyingPx);
+      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
+      FIELD_SET(*this, FIX::UnderlyingEndPrice);
+      FIELD_SET(*this, FIX::UnderlyingStartValue);
+      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
+      FIELD_SET(*this, FIX::UnderlyingEndValue);
+      FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
+      FIELD_SET(*this, FIX::UnderlyingFXRate);
+      FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
     };
-    FIELD_SET(*this, FIX::ResponseTransportType);
-    FIELD_SET(*this, FIX::ResponseDestination);
-    FIELD_SET(*this, FIX::Text);
-    FIELD_SET(*this, FIX::EncodedTextLen);
-    FIELD_SET(*this, FIX::EncodedText);
+    FIELD_SET(*this, FIX::MatchStatus);
+    FIELD_SET(*this, FIX::MatchType);
+    FIELD_SET(*this, FIX::CopyMsgIndicator);
+    FIELD_SET(*this, FIX::PublishTrdIndicator);
+    FIELD_SET(*this, FIX::ShortSaleReason);
     FIELD_SET(*this, FIX::NoLegs);
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,687,690,683,564,565,539,654,566,587,588,637,990,675,1073,1074,1075,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1001,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1017,687,690,990,683,564,565,539,654,566,587,588,637,675,1073,1074,1075,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
@@ -133,6 +234,8 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegTimeUnit);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -148,10 +251,10 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegQty);
       FIELD_SET(*this, FIX::LegSwapType);
+      FIELD_SET(*this, FIX::LegReportID);
       FIELD_SET(*this, FIX::NoLegStipulations);
       class NoLegStipulations: public FIX::Group
       {
@@ -184,41 +287,30 @@ namespace FIX50
       FIELD_SET(*this, FIX::LegSettlType);
       FIELD_SET(*this, FIX::LegSettlDate);
       FIELD_SET(*this, FIX::LegLastPx);
-      FIELD_SET(*this, FIX::LegReportID);
       FIELD_SET(*this, FIX::LegSettlCurrency);
       FIELD_SET(*this, FIX::LegLastForwardPoints);
       FIELD_SET(*this, FIX::LegCalculatedCcyLastQty);
       FIELD_SET(*this, FIX::LegGrossTradeAmt);
     };
+    FIELD_SET(*this, FIX::NoTrdRegTimestamps);
+    class NoTrdRegTimestamps: public FIX::Group
+    {
+    public:
+    NoTrdRegTimestamps() : FIX::Group(768,769,FIX::message_order(769,770,771,1033,1034,1035,0)) {}
+      FIELD_SET(*this, FIX::TrdRegTimestamp);
+      FIELD_SET(*this, FIX::TrdRegTimestampType);
+      FIELD_SET(*this, FIX::TrdRegTimestampOrigin);
+      FIELD_SET(*this, FIX::DeskType);
+      FIELD_SET(*this, FIX::DeskTypeSource);
+      FIELD_SET(*this, FIX::DeskOrderHandlingInst);
+    };
+    FIELD_SET(*this, FIX::ResponseTransportType);
+    FIELD_SET(*this, FIX::ResponseDestination);
+    FIELD_SET(*this, FIX::Text);
+    FIELD_SET(*this, FIX::EncodedTextLen);
+    FIELD_SET(*this, FIX::EncodedText);
+    FIELD_SET(*this, FIX::AsOfIndicator);
     FIELD_SET(*this, FIX::ClearingFeeIndicator);
-    FIELD_SET(*this, FIX::OrdStatus);
-    FIELD_SET(*this, FIX::ExecRestatementReason);
-    FIELD_SET(*this, FIX::PreviouslyReported);
-    FIELD_SET(*this, FIX::PriceType);
-    FIELD_SET(*this, FIX::UnderlyingTradingSessionID);
-    FIELD_SET(*this, FIX::QtyType);
-    FIELD_SET(*this, FIX::UnderlyingTradingSessionSubID);
-    FIELD_SET(*this, FIX::LastQty);
-    FIELD_SET(*this, FIX::LastPx);
-    FIELD_SET(*this, FIX::LastParPx);
-    FIELD_SET(*this, FIX::LastSpotRate);
-    FIELD_SET(*this, FIX::LastForwardPoints);
-    FIELD_SET(*this, FIX::LastMkt);
-    FIELD_SET(*this, FIX::TradeDate);
-    FIELD_SET(*this, FIX::ClearingBusinessDate);
-    FIELD_SET(*this, FIX::AvgPx);
-    FIELD_SET(*this, FIX::AvgPxIndicator);
-    FIELD_SET(*this, FIX::MultiLegReportingType);
-    FIELD_SET(*this, FIX::TradeLegRefID);
-    FIELD_SET(*this, FIX::SettlType);
-    FIELD_SET(*this, FIX::MatchStatus);
-    FIELD_SET(*this, FIX::MatchType);
-    FIELD_SET(*this, FIX::CopyMsgIndicator);
-    FIELD_SET(*this, FIX::PublishTrdIndicator);
-    FIELD_SET(*this, FIX::ShortSaleReason);
-    FIELD_SET(*this, FIX::SettlDate);
-    FIELD_SET(*this, FIX::SettlSessID);
-    FIELD_SET(*this, FIX::SettlSessSubID);
     FIELD_SET(*this, FIX::NoPosAmt);
     class NoPosAmt: public FIX::Group
     {
@@ -236,7 +328,7 @@ namespace FIX50
     class NoSides: public FIX::Group
     {
     public:
-    NoSides() : FIX::Group(552,54,FIX::message_order(54,37,198,11,526,66,453,1,660,581,81,575,576,578,579,821,15,376,377,528,529,582,40,18,483,336,625,943,12,13,479,497,157,230,158,159,738,920,921,922,238,237,118,119,120,155,156,77,752,518,232,136,825,826,591,70,78,1093,1072,1057,1009,1005,1006,1007,83,1008,1016,0)) {}
+    NoSides() : FIX::Group(552,54,FIX::message_order(54,37,198,11,526,66,453,1,660,581,81,575,1093,576,578,579,821,15,376,377,528,529,582,40,18,483,336,625,943,12,13,479,497,157,230,158,159,738,920,921,922,238,237,118,119,120,155,156,77,752,518,232,136,825,826,591,70,78,1072,1057,1009,1005,1006,1007,83,1008,1016,0)) {}
       FIELD_SET(*this, FIX::Side);
       FIELD_SET(*this, FIX::OrderID);
       FIELD_SET(*this, FIX::SecondaryOrderID);
@@ -265,6 +357,7 @@ namespace FIX50
       FIELD_SET(*this, FIX::AccountType);
       FIELD_SET(*this, FIX::ProcessCode);
       FIELD_SET(*this, FIX::OddLot);
+      FIELD_SET(*this, FIX::LotType);
       FIELD_SET(*this, FIX::NoClearingInstructions);
       class NoClearingInstructions: public FIX::Group
       {
@@ -371,7 +464,6 @@ namespace FIX50
         FIELD_SET(*this, FIX::SecondaryIndividualAllocID);
         FIELD_SET(*this, FIX::AllocClearingFeeIndicator);
       };
-      FIELD_SET(*this, FIX::LotType);
       FIELD_SET(*this, FIX::SideGrossTradeAmt);
       FIELD_SET(*this, FIX::AggressorIndicator);
       FIELD_SET(*this, FIX::SideQty);
@@ -390,98 +482,9 @@ namespace FIX50
         FIELD_SET(*this, FIX::SideTrdRegTimestampSrc);
       };
     };
-    FIELD_SET(*this, FIX::AsOfIndicator);
-    FIELD_SET(*this, FIX::TradeID);
-    FIELD_SET(*this, FIX::SecondaryTradeID);
-    FIELD_SET(*this, FIX::FirmTradeID);
-    FIELD_SET(*this, FIX::SecondaryFirmTradeID);
-    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
-    FIELD_SET(*this, FIX::LastSwapPoints);
-    FIELD_SET(*this, FIX::GrossTradeAmt);
-    FIELD_SET(*this, FIX::NoRootPartyIDs);
-    class NoRootPartyIDs: public FIX::Group
-    {
-    public:
-    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
-      FIELD_SET(*this, FIX::RootPartyID);
-      FIELD_SET(*this, FIX::RootPartyIDSource);
-      FIELD_SET(*this, FIX::RootPartyRole);
-      FIELD_SET(*this, FIX::NoRootPartySubIDs);
-      class NoRootPartySubIDs: public FIX::Group
-      {
-      public:
-      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
-        FIELD_SET(*this, FIX::RootPartySubID);
-        FIELD_SET(*this, FIX::RootPartySubIDType);
-      };
-    };
-    FIELD_SET(*this, FIX::TradeHandlingInstr);
-    FIELD_SET(*this, FIX::OrigTradeHandlingInstr);
-    FIELD_SET(*this, FIX::OrigTradeDate);
-    FIELD_SET(*this, FIX::OrigTradeID);
-    FIELD_SET(*this, FIX::OrigSecondaryTradeID);
-    FIELD_SET(*this, FIX::NoUnderlyings);
-    class NoUnderlyings: public FIX::Group
-    {
-    public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,0)) {}
-      FIELD_SET(*this, FIX::UnderlyingSymbol);
-      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
-      FIELD_SET(*this, FIX::UnderlyingSecurityID);
-      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
-      FIELD_SET(*this, FIX::UnderlyingProduct);
-      FIELD_SET(*this, FIX::UnderlyingCFICode);
-      FIELD_SET(*this, FIX::UnderlyingSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
-      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
-      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
-      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
-      FIELD_SET(*this, FIX::UnderlyingIssueDate);
-      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
-      FIELD_SET(*this, FIX::UnderlyingFactor);
-      FIELD_SET(*this, FIX::UnderlyingCreditRating);
-      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
-      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
-      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
-      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
-      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
-      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
-      FIELD_SET(*this, FIX::UnderlyingCouponRate);
-      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
-      FIELD_SET(*this, FIX::UnderlyingIssuer);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
-      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::UnderlyingCPProgram);
-      FIELD_SET(*this, FIX::UnderlyingCPRegType);
-      FIELD_SET(*this, FIX::UnderlyingCurrency);
-      FIELD_SET(*this, FIX::UnderlyingQty);
-      FIELD_SET(*this, FIX::UnderlyingPx);
-      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
-      FIELD_SET(*this, FIX::UnderlyingEndPrice);
-      FIELD_SET(*this, FIX::UnderlyingStartValue);
-      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
-      FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
-      FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
-      FIELD_SET(*this, FIX::UnderlyingFXRate);
-      FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-    };
     FIELD_SET(*this, FIX::RptSys);
+    FIELD_SET(*this, FIX::GrossTradeAmt);
+    FIELD_SET(*this, FIX::SettlDate);
   };
 
 }
