@@ -15,14 +15,23 @@ namespace FIX50SP2
     MarketDataIncrementalRefresh(const MarketDataIncrementalRefresh& m) : Message(m) {}
     static FIX::MsgType MsgType() { return FIX::MsgType("X"); }
 
+    FIELD_SET(*this, FIX::ApplID);
+    FIELD_SET(*this, FIX::ApplSeqNum);
+    FIELD_SET(*this, FIX::ApplLastSeqNum);
+    FIELD_SET(*this, FIX::ApplResendFlag);
+    FIELD_SET(*this, FIX::MDBookType);
+    FIELD_SET(*this, FIX::MDFeedType);
+    FIELD_SET(*this, FIX::TradeDate);
     FIELD_SET(*this, FIX::MDReqID);
     FIELD_SET(*this, FIX::NoMDEntries);
     class NoMDEntries: public FIX::Group
     {
     public:
-    NoMDEntries() : FIX::Group(268,279,FIX::message_order(279,285,269,278,280,55,65,48,22,460,461,167,762,200,541,224,225,239,226,227,228,255,543,470,471,472,240,202,947,206,231,223,207,106,348,349,107,350,351,691,667,875,876,873,874,965,966,1049,967,968,969,970,971,996,997,1079,1151,1146,1147,1227,1191,1192,1193,1194,1195,1196,1198,1199,1200,201,1244,1242,1197,1435,1439,1449,1450,1451,1452,1457,1458,1478,1479,1480,1481,1482,711,555,291,292,270,15,271,272,273,274,275,336,625,276,277,282,283,284,286,59,432,126,110,18,287,37,299,288,289,346,290,546,811,451,58,354,355,528,1024,332,333,1020,63,64,1070,83,1048,1026,1027,1023,453,198,40,1173,264,423,235,236,701,696,697,698,218,220,221,222,662,663,699,761,1177,1093,326,327,828,574,1003,483,60,1175,120,1445,1025,31,1500,0)) {}
+    NoMDEntries() : FIX::Group(268,279,FIX::message_order(279,285,1173,264,269,278,280,55,65,48,22,460,1227,1151,461,167,762,200,541,1079,966,1049,965,224,225,239,226,227,228,255,543,470,471,472,240,202,947,967,968,206,231,969,1146,996,1147,1191,1192,1193,1194,1195,1196,1197,1198,1199,1200,201,1244,1242,997,223,207,970,971,106,348,349,107,350,351,691,667,875,876,873,874,1435,1439,1449,1450,1451,1452,1457,1458,1478,1479,1480,1481,1482,711,555,291,292,270,423,235,236,701,696,697,698,218,220,221,222,662,663,699,761,40,15,271,1177,1093,272,273,274,275,336,625,326,327,276,277,828,574,282,283,284,286,59,432,126,110,18,287,37,198,299,1003,288,289,346,290,546,811,451,58,354,355,1023,528,1024,332,333,1020,63,64,483,60,1070,83,1048,1026,1027,1175,453,120,1445,1025,31,1500,0)) {}
       FIELD_SET(*this, FIX::MDUpdateAction);
       FIELD_SET(*this, FIX::DeleteReason);
+      FIELD_SET(*this, FIX::MDSubBookType);
+      FIELD_SET(*this, FIX::MarketDepth);
       FIELD_SET(*this, FIX::MDEntryType);
       FIELD_SET(*this, FIX::MDEntryID);
       FIELD_SET(*this, FIX::MDEntryRefID);
@@ -31,11 +40,17 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::SecurityID);
       FIELD_SET(*this, FIX::SecurityIDSource);
       FIELD_SET(*this, FIX::Product);
+      FIELD_SET(*this, FIX::ProductComplex);
+      FIELD_SET(*this, FIX::SecurityGroup);
       FIELD_SET(*this, FIX::CFICode);
       FIELD_SET(*this, FIX::SecurityType);
       FIELD_SET(*this, FIX::SecuritySubType);
       FIELD_SET(*this, FIX::MaturityMonthYear);
       FIELD_SET(*this, FIX::MaturityDate);
+      FIELD_SET(*this, FIX::MaturityTime);
+      FIELD_SET(*this, FIX::SettleOnOpenFlag);
+      FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+      FIELD_SET(*this, FIX::SecurityStatus);
       FIELD_SET(*this, FIX::CouponPaymentDate);
       FIELD_SET(*this, FIX::IssueDate);
       FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -50,10 +65,32 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::RedemptionDate);
       FIELD_SET(*this, FIX::StrikePrice);
       FIELD_SET(*this, FIX::StrikeCurrency);
+      FIELD_SET(*this, FIX::StrikeMultiplier);
+      FIELD_SET(*this, FIX::StrikeValue);
       FIELD_SET(*this, FIX::OptAttribute);
       FIELD_SET(*this, FIX::ContractMultiplier);
+      FIELD_SET(*this, FIX::MinPriceIncrement);
+      FIELD_SET(*this, FIX::MinPriceIncrementAmount);
+      FIELD_SET(*this, FIX::UnitOfMeasure);
+      FIELD_SET(*this, FIX::UnitOfMeasureQty);
+      FIELD_SET(*this, FIX::PriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::SettlMethod);
+      FIELD_SET(*this, FIX::ExerciseStyle);
+      FIELD_SET(*this, FIX::OptPayoutAmount);
+      FIELD_SET(*this, FIX::PriceQuoteMethod);
+      FIELD_SET(*this, FIX::ValuationMethod);
+      FIELD_SET(*this, FIX::ListMethod);
+      FIELD_SET(*this, FIX::CapPrice);
+      FIELD_SET(*this, FIX::FloorPrice);
+      FIELD_SET(*this, FIX::PutOrCall);
+      FIELD_SET(*this, FIX::FlexibleIndicator);
+      FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
+      FIELD_SET(*this, FIX::TimeUnit);
       FIELD_SET(*this, FIX::CouponRate);
       FIELD_SET(*this, FIX::SecurityExchange);
+      FIELD_SET(*this, FIX::PositionLimit);
+      FIELD_SET(*this, FIX::NTPositionLimit);
       FIELD_SET(*this, FIX::Issuer);
       FIELD_SET(*this, FIX::EncodedIssuerLen);
       FIELD_SET(*this, FIX::EncodedIssuer);
@@ -66,34 +103,6 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::CPRegType);
       FIELD_SET(*this, FIX::DatedDate);
       FIELD_SET(*this, FIX::InterestAccrualDate);
-      FIELD_SET(*this, FIX::SecurityStatus);
-      FIELD_SET(*this, FIX::SettleOnOpenFlag);
-      FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-      FIELD_SET(*this, FIX::StrikeMultiplier);
-      FIELD_SET(*this, FIX::StrikeValue);
-      FIELD_SET(*this, FIX::MinPriceIncrement);
-      FIELD_SET(*this, FIX::PositionLimit);
-      FIELD_SET(*this, FIX::NTPositionLimit);
-      FIELD_SET(*this, FIX::UnitOfMeasure);
-      FIELD_SET(*this, FIX::TimeUnit);
-      FIELD_SET(*this, FIX::MaturityTime);
-      FIELD_SET(*this, FIX::SecurityGroup);
-      FIELD_SET(*this, FIX::MinPriceIncrementAmount);
-      FIELD_SET(*this, FIX::UnitOfMeasureQty);
-      FIELD_SET(*this, FIX::ProductComplex);
-      FIELD_SET(*this, FIX::PriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::SettlMethod);
-      FIELD_SET(*this, FIX::ExerciseStyle);
-      FIELD_SET(*this, FIX::OptPayoutAmount);
-      FIELD_SET(*this, FIX::PriceQuoteMethod);
-      FIELD_SET(*this, FIX::ListMethod);
-      FIELD_SET(*this, FIX::CapPrice);
-      FIELD_SET(*this, FIX::FloorPrice);
-      FIELD_SET(*this, FIX::PutOrCall);
-      FIELD_SET(*this, FIX::FlexibleIndicator);
-      FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
-      FIELD_SET(*this, FIX::ValuationMethod);
       FIELD_SET(*this, FIX::ContractMultiplierUnit);
       FIELD_SET(*this, FIX::FlowScheduleType);
       FIELD_SET(*this, FIX::RestructuringType);
@@ -111,7 +120,7 @@ namespace FIX50SP2
       class NoUnderlyings: public FIX::Group
       {
       public:
-      NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,1213,315,1419,1423,1424,1425,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
+      NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,1213,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1423,1424,1425,1000,1419,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,315,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
         FIELD_SET(*this, FIX::UnderlyingSymbol);
         FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
         FIELD_SET(*this, FIX::UnderlyingSecurityID);
@@ -122,6 +131,7 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
         FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
         FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+        FIELD_SET(*this, FIX::UnderlyingMaturityTime);
         FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
         FIELD_SET(*this, FIX::UnderlyingIssueDate);
         FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -138,6 +148,12 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
         FIELD_SET(*this, FIX::UnderlyingOptAttribute);
         FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
+        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+        FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
         FIELD_SET(*this, FIX::UnderlyingCouponRate);
         FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
         FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -148,31 +164,24 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
         FIELD_SET(*this, FIX::UnderlyingCPProgram);
         FIELD_SET(*this, FIX::UnderlyingCPRegType);
+        FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
         FIELD_SET(*this, FIX::UnderlyingCurrency);
         FIELD_SET(*this, FIX::UnderlyingQty);
+        FIELD_SET(*this, FIX::UnderlyingSettlementType);
+        FIELD_SET(*this, FIX::UnderlyingCashAmount);
+        FIELD_SET(*this, FIX::UnderlyingCashType);
         FIELD_SET(*this, FIX::UnderlyingPx);
         FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
         FIELD_SET(*this, FIX::UnderlyingEndPrice);
         FIELD_SET(*this, FIX::UnderlyingStartValue);
         FIELD_SET(*this, FIX::UnderlyingCurrentValue);
         FIELD_SET(*this, FIX::UnderlyingEndValue);
-        FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-        FIELD_SET(*this, FIX::UnderlyingSettlementType);
-        FIELD_SET(*this, FIX::UnderlyingCashAmount);
-        FIELD_SET(*this, FIX::UnderlyingCashType);
-        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-        FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-        FIELD_SET(*this, FIX::UnderlyingCapValue);
-        FIELD_SET(*this, FIX::UnderlyingSettlMethod);
         FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
         FIELD_SET(*this, FIX::UnderlyingFXRate);
         FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-        FIELD_SET(*this, FIX::UnderlyingMaturityTime);
+        FIELD_SET(*this, FIX::UnderlyingCapValue);
+        FIELD_SET(*this, FIX::UnderlyingSettlMethod);
         FIELD_SET(*this, FIX::UnderlyingPutOrCall);
-        FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
-        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
-        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
-        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
         FIELD_SET(*this, FIX::UnderlyingContractMultiplierUnit);
         FIELD_SET(*this, FIX::UnderlyingFlowScheduleType);
         FIELD_SET(*this, FIX::UnderlyingRestructuringType);
@@ -186,7 +195,7 @@ namespace FIX50SP2
       class NoLegs: public FIX::Group
       {
       public:
-      NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,1017,566,1212,1358,1420,1224,1421,1422,1436,1440,0)) {}
+      NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,1212,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1224,1421,1422,1001,1420,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1358,1017,1436,1440,0)) {}
         FIELD_SET(*this, FIX::LegSymbol);
         FIELD_SET(*this, FIX::LegSymbolSfx);
         FIELD_SET(*this, FIX::LegSecurityID);
@@ -197,6 +206,7 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegSecuritySubType);
         FIELD_SET(*this, FIX::LegMaturityMonthYear);
         FIELD_SET(*this, FIX::LegMaturityDate);
+        FIELD_SET(*this, FIX::LegMaturityTime);
         FIELD_SET(*this, FIX::LegCouponPaymentDate);
         FIELD_SET(*this, FIX::LegIssueDate);
         FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
@@ -213,6 +223,12 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegStrikeCurrency);
         FIELD_SET(*this, FIX::LegOptAttribute);
         FIELD_SET(*this, FIX::LegContractMultiplier);
+        FIELD_SET(*this, FIX::LegUnitOfMeasure);
+        FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
+        FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegTimeUnit);
+        FIELD_SET(*this, FIX::LegExerciseStyle);
         FIELD_SET(*this, FIX::LegCouponRate);
         FIELD_SET(*this, FIX::LegSecurityExchange);
         FIELD_SET(*this, FIX::LegIssuer);
@@ -228,32 +244,53 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegDatedDate);
         FIELD_SET(*this, FIX::LegContractSettlMonth);
         FIELD_SET(*this, FIX::LegInterestAccrualDate);
-        FIELD_SET(*this, FIX::LegUnitOfMeasure);
-        FIELD_SET(*this, FIX::LegTimeUnit);
-        FIELD_SET(*this, FIX::LegOptionRatio);
-        FIELD_SET(*this, FIX::LegPrice);
-        FIELD_SET(*this, FIX::LegMaturityTime);
         FIELD_SET(*this, FIX::LegPutOrCall);
-        FIELD_SET(*this, FIX::LegExerciseStyle);
-        FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
-        FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
-        FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegOptionRatio);
         FIELD_SET(*this, FIX::LegContractMultiplierUnit);
         FIELD_SET(*this, FIX::LegFlowScheduleType);
       };
       FIELD_SET(*this, FIX::FinancialStatus);
       FIELD_SET(*this, FIX::CorporateAction);
       FIELD_SET(*this, FIX::MDEntryPx);
+      FIELD_SET(*this, FIX::PriceType);
+      FIELD_SET(*this, FIX::YieldType);
+      FIELD_SET(*this, FIX::Yield);
+      FIELD_SET(*this, FIX::YieldCalcDate);
+      FIELD_SET(*this, FIX::YieldRedemptionDate);
+      FIELD_SET(*this, FIX::YieldRedemptionPrice);
+      FIELD_SET(*this, FIX::YieldRedemptionPriceType);
+      FIELD_SET(*this, FIX::Spread);
+      FIELD_SET(*this, FIX::BenchmarkCurveCurrency);
+      FIELD_SET(*this, FIX::BenchmarkCurveName);
+      FIELD_SET(*this, FIX::BenchmarkCurvePoint);
+      FIELD_SET(*this, FIX::BenchmarkPrice);
+      FIELD_SET(*this, FIX::BenchmarkPriceType);
+      FIELD_SET(*this, FIX::BenchmarkSecurityID);
+      FIELD_SET(*this, FIX::BenchmarkSecurityIDSource);
+      FIELD_SET(*this, FIX::OrdType);
       FIELD_SET(*this, FIX::Currency);
       FIELD_SET(*this, FIX::MDEntrySize);
+      FIELD_SET(*this, FIX::NoOfSecSizes);
+      class NoOfSecSizes: public FIX::Group
+      {
+      public:
+      NoOfSecSizes() : FIX::Group(1177,1178,FIX::message_order(1178,1179,0)) {}
+        FIELD_SET(*this, FIX::MDSecSizeType);
+        FIELD_SET(*this, FIX::MDSecSize);
+      };
+      FIELD_SET(*this, FIX::LotType);
       FIELD_SET(*this, FIX::MDEntryDate);
       FIELD_SET(*this, FIX::MDEntryTime);
       FIELD_SET(*this, FIX::TickDirection);
       FIELD_SET(*this, FIX::MDMkt);
       FIELD_SET(*this, FIX::TradingSessionID);
       FIELD_SET(*this, FIX::TradingSessionSubID);
+      FIELD_SET(*this, FIX::SecurityTradingStatus);
+      FIELD_SET(*this, FIX::HaltReasonInt);
       FIELD_SET(*this, FIX::QuoteCondition);
       FIELD_SET(*this, FIX::TradeCondition);
+      FIELD_SET(*this, FIX::TrdType);
+      FIELD_SET(*this, FIX::MatchType);
       FIELD_SET(*this, FIX::MDEntryOriginator);
       FIELD_SET(*this, FIX::LocationID);
       FIELD_SET(*this, FIX::DeskID);
@@ -265,7 +302,9 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::ExecInst);
       FIELD_SET(*this, FIX::SellerDays);
       FIELD_SET(*this, FIX::OrderID);
+      FIELD_SET(*this, FIX::SecondaryOrderID);
       FIELD_SET(*this, FIX::QuoteEntryID);
+      FIELD_SET(*this, FIX::TradeID);
       FIELD_SET(*this, FIX::MDEntryBuyer);
       FIELD_SET(*this, FIX::MDEntrySeller);
       FIELD_SET(*this, FIX::NumberOfOrders);
@@ -276,6 +315,7 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::Text);
       FIELD_SET(*this, FIX::EncodedTextLen);
       FIELD_SET(*this, FIX::EncodedText);
+      FIELD_SET(*this, FIX::MDPriceLevel);
       FIELD_SET(*this, FIX::OrderCapacity);
       FIELD_SET(*this, FIX::MDOriginType);
       FIELD_SET(*this, FIX::HighPx);
@@ -283,12 +323,20 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::TradeVolume);
       FIELD_SET(*this, FIX::SettlType);
       FIELD_SET(*this, FIX::SettlDate);
+      FIELD_SET(*this, FIX::TransBkdTime);
+      FIELD_SET(*this, FIX::TransactTime);
       FIELD_SET(*this, FIX::MDQuoteType);
       FIELD_SET(*this, FIX::RptSeq);
       FIELD_SET(*this, FIX::DealingCapacity);
       FIELD_SET(*this, FIX::MDEntrySpotRate);
       FIELD_SET(*this, FIX::MDEntryForwardPoints);
-      FIELD_SET(*this, FIX::MDPriceLevel);
+      FIELD_SET(*this, FIX::NoStatsIndicators);
+      class NoStatsIndicators: public FIX::Group
+      {
+      public:
+      NoStatsIndicators() : FIX::Group(1175,1176,FIX::message_order(1176,0)) {}
+        FIELD_SET(*this, FIX::StatsType);
+      };
       FIELD_SET(*this, FIX::NoPartyIDs);
       class NoPartyIDs: public FIX::Group
       {
@@ -306,48 +354,6 @@ namespace FIX50SP2
           FIELD_SET(*this, FIX::PartySubIDType);
         };
       };
-      FIELD_SET(*this, FIX::SecondaryOrderID);
-      FIELD_SET(*this, FIX::OrdType);
-      FIELD_SET(*this, FIX::MDSubBookType);
-      FIELD_SET(*this, FIX::MarketDepth);
-      FIELD_SET(*this, FIX::PriceType);
-      FIELD_SET(*this, FIX::YieldType);
-      FIELD_SET(*this, FIX::Yield);
-      FIELD_SET(*this, FIX::YieldCalcDate);
-      FIELD_SET(*this, FIX::YieldRedemptionDate);
-      FIELD_SET(*this, FIX::YieldRedemptionPrice);
-      FIELD_SET(*this, FIX::YieldRedemptionPriceType);
-      FIELD_SET(*this, FIX::Spread);
-      FIELD_SET(*this, FIX::BenchmarkCurveCurrency);
-      FIELD_SET(*this, FIX::BenchmarkCurveName);
-      FIELD_SET(*this, FIX::BenchmarkCurvePoint);
-      FIELD_SET(*this, FIX::BenchmarkPrice);
-      FIELD_SET(*this, FIX::BenchmarkPriceType);
-      FIELD_SET(*this, FIX::BenchmarkSecurityID);
-      FIELD_SET(*this, FIX::BenchmarkSecurityIDSource);
-      FIELD_SET(*this, FIX::NoOfSecSizes);
-      class NoOfSecSizes: public FIX::Group
-      {
-      public:
-      NoOfSecSizes() : FIX::Group(1177,1178,FIX::message_order(1178,1179,0)) {}
-        FIELD_SET(*this, FIX::MDSecSizeType);
-        FIELD_SET(*this, FIX::MDSecSize);
-      };
-      FIELD_SET(*this, FIX::LotType);
-      FIELD_SET(*this, FIX::SecurityTradingStatus);
-      FIELD_SET(*this, FIX::HaltReasonInt);
-      FIELD_SET(*this, FIX::TrdType);
-      FIELD_SET(*this, FIX::MatchType);
-      FIELD_SET(*this, FIX::TradeID);
-      FIELD_SET(*this, FIX::TransBkdTime);
-      FIELD_SET(*this, FIX::TransactTime);
-      FIELD_SET(*this, FIX::NoStatsIndicators);
-      class NoStatsIndicators: public FIX::Group
-      {
-      public:
-      NoStatsIndicators() : FIX::Group(1175,1176,FIX::message_order(1176,0)) {}
-        FIELD_SET(*this, FIX::StatsType);
-      };
       FIELD_SET(*this, FIX::SettlCurrency);
       FIELD_SET(*this, FIX::NoRateSources);
       class NoRateSources: public FIX::Group
@@ -364,9 +370,6 @@ namespace FIX50SP2
     };
     FIELD_SET(*this, FIX::ApplQueueDepth);
     FIELD_SET(*this, FIX::ApplQueueResolution);
-    FIELD_SET(*this, FIX::MDBookType);
-    FIELD_SET(*this, FIX::MDFeedType);
-    FIELD_SET(*this, FIX::TradeDate);
     FIELD_SET(*this, FIX::NoRoutingIDs);
     class NoRoutingIDs: public FIX::Group
     {
@@ -375,10 +378,6 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::RoutingType);
       FIELD_SET(*this, FIX::RoutingID);
     };
-    FIELD_SET(*this, FIX::ApplID);
-    FIELD_SET(*this, FIX::ApplSeqNum);
-    FIELD_SET(*this, FIX::ApplLastSeqNum);
-    FIELD_SET(*this, FIX::ApplResendFlag);
   };
 
 }
