@@ -15,17 +15,36 @@ namespace FIX50SP2
     MarketDataSnapshotFullRefresh(const MarketDataSnapshotFullRefresh& m) : Message(m) {}
     static FIX::MsgType MsgType() { return FIX::MsgType("W"); }
 
+    FIELD_SET(*this, FIX::ApplID);
+    FIELD_SET(*this, FIX::ApplSeqNum);
+    FIELD_SET(*this, FIX::ApplLastSeqNum);
+    FIELD_SET(*this, FIX::ApplResendFlag);
+    FIELD_SET(*this, FIX::TotNumReports);
+    FIELD_SET(*this, FIX::MDReportID);
+    FIELD_SET(*this, FIX::ClearingBusinessDate);
+    FIELD_SET(*this, FIX::MDBookType);
+    FIELD_SET(*this, FIX::MDSubBookType);
+    FIELD_SET(*this, FIX::MarketDepth);
+    FIELD_SET(*this, FIX::MDFeedType);
+    FIELD_SET(*this, FIX::RefreshIndicator);
+    FIELD_SET(*this, FIX::TradeDate);
     FIELD_SET(*this, FIX::MDReqID);
     FIELD_SET(*this, FIX::Symbol);
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
     FIELD_SET(*this, FIX::SecurityIDSource);
     FIELD_SET(*this, FIX::Product);
+    FIELD_SET(*this, FIX::ProductComplex);
+    FIELD_SET(*this, FIX::SecurityGroup);
     FIELD_SET(*this, FIX::CFICode);
     FIELD_SET(*this, FIX::SecurityType);
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -40,10 +59,32 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
+    FIELD_SET(*this, FIX::StrikeMultiplier);
+    FIELD_SET(*this, FIX::StrikeValue);
     FIELD_SET(*this, FIX::OptAttribute);
     FIELD_SET(*this, FIX::ContractMultiplier);
+    FIELD_SET(*this, FIX::MinPriceIncrement);
+    FIELD_SET(*this, FIX::MinPriceIncrementAmount);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
+    FIELD_SET(*this, FIX::UnitOfMeasureQty);
+    FIELD_SET(*this, FIX::PriceUnitOfMeasure);
+    FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
+    FIELD_SET(*this, FIX::SettlMethod);
+    FIELD_SET(*this, FIX::ExerciseStyle);
+    FIELD_SET(*this, FIX::OptPayoutAmount);
+    FIELD_SET(*this, FIX::PriceQuoteMethod);
+    FIELD_SET(*this, FIX::ValuationMethod);
+    FIELD_SET(*this, FIX::ListMethod);
+    FIELD_SET(*this, FIX::CapPrice);
+    FIELD_SET(*this, FIX::FloorPrice);
+    FIELD_SET(*this, FIX::PutOrCall);
+    FIELD_SET(*this, FIX::FlexibleIndicator);
+    FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
+    FIELD_SET(*this, FIX::TimeUnit);
     FIELD_SET(*this, FIX::CouponRate);
     FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
     FIELD_SET(*this, FIX::Issuer);
     FIELD_SET(*this, FIX::EncodedIssuerLen);
     FIELD_SET(*this, FIX::EncodedIssuer);
@@ -56,34 +97,6 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::CPRegType);
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-    FIELD_SET(*this, FIX::StrikeMultiplier);
-    FIELD_SET(*this, FIX::StrikeValue);
-    FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
-    FIELD_SET(*this, FIX::SecurityGroup);
-    FIELD_SET(*this, FIX::MinPriceIncrementAmount);
-    FIELD_SET(*this, FIX::UnitOfMeasureQty);
-    FIELD_SET(*this, FIX::ProductComplex);
-    FIELD_SET(*this, FIX::PriceUnitOfMeasure);
-    FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
-    FIELD_SET(*this, FIX::SettlMethod);
-    FIELD_SET(*this, FIX::ExerciseStyle);
-    FIELD_SET(*this, FIX::OptPayoutAmount);
-    FIELD_SET(*this, FIX::PriceQuoteMethod);
-    FIELD_SET(*this, FIX::ListMethod);
-    FIELD_SET(*this, FIX::CapPrice);
-    FIELD_SET(*this, FIX::FloorPrice);
-    FIELD_SET(*this, FIX::PutOrCall);
-    FIELD_SET(*this, FIX::FlexibleIndicator);
-    FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
-    FIELD_SET(*this, FIX::ValuationMethod);
     FIELD_SET(*this, FIX::ContractMultiplierUnit);
     FIELD_SET(*this, FIX::FlowScheduleType);
     FIELD_SET(*this, FIX::RestructuringType);
@@ -101,7 +114,7 @@ namespace FIX50SP2
     class NoUnderlyings: public FIX::Group
     {
     public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,1213,315,1419,1423,1424,1425,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,1213,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1423,1424,1425,1000,1419,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,315,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
       FIELD_SET(*this, FIX::UnderlyingSymbol);
       FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
       FIELD_SET(*this, FIX::UnderlyingSecurityID);
@@ -112,6 +125,7 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
       FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
       FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
       FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
       FIELD_SET(*this, FIX::UnderlyingIssueDate);
       FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -128,6 +142,12 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
       FIELD_SET(*this, FIX::UnderlyingOptAttribute);
       FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
       FIELD_SET(*this, FIX::UnderlyingCouponRate);
       FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
       FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -138,31 +158,24 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
       FIELD_SET(*this, FIX::UnderlyingCPProgram);
       FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
       FIELD_SET(*this, FIX::UnderlyingCurrency);
       FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
       FIELD_SET(*this, FIX::UnderlyingPx);
       FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
       FIELD_SET(*this, FIX::UnderlyingEndPrice);
       FIELD_SET(*this, FIX::UnderlyingStartValue);
       FIELD_SET(*this, FIX::UnderlyingCurrentValue);
       FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
       FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
       FIELD_SET(*this, FIX::UnderlyingFXRate);
       FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
       FIELD_SET(*this, FIX::UnderlyingPutOrCall);
-      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
       FIELD_SET(*this, FIX::UnderlyingContractMultiplierUnit);
       FIELD_SET(*this, FIX::UnderlyingFlowScheduleType);
       FIELD_SET(*this, FIX::UnderlyingRestructuringType);
@@ -176,7 +189,7 @@ namespace FIX50SP2
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,1017,566,1212,1358,1420,1224,1421,1422,1436,1440,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,1212,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1224,1421,1422,1001,1420,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1358,1017,1436,1440,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
@@ -187,6 +200,7 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegSecuritySubType);
       FIELD_SET(*this, FIX::LegMaturityMonthYear);
       FIELD_SET(*this, FIX::LegMaturityDate);
+      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegCouponPaymentDate);
       FIELD_SET(*this, FIX::LegIssueDate);
       FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
@@ -203,6 +217,12 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegExerciseStyle);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -218,16 +238,8 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
-      FIELD_SET(*this, FIX::LegOptionRatio);
-      FIELD_SET(*this, FIX::LegPrice);
-      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegPutOrCall);
-      FIELD_SET(*this, FIX::LegExerciseStyle);
-      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegContractMultiplierUnit);
       FIELD_SET(*this, FIX::LegFlowScheduleType);
     };
@@ -238,17 +250,45 @@ namespace FIX50SP2
     class NoMDEntries: public FIX::Group
     {
     public:
-    NoMDEntries() : FIX::Group(268,269,FIX::message_order(269,270,15,271,272,273,274,275,336,625,276,277,282,283,284,286,59,432,126,110,18,287,37,299,288,289,346,290,546,811,58,354,355,1023,528,1024,332,333,1020,63,64,1070,83,1048,1026,1027,278,453,198,40,423,235,236,701,696,697,698,218,220,221,222,662,663,699,761,1177,1093,326,327,120,1445,828,1025,31,0)) {}
+    NoMDEntries() : FIX::Group(268,269,FIX::message_order(269,278,270,423,235,236,701,696,697,698,218,220,221,222,662,663,699,761,40,15,271,1177,1093,272,273,274,275,336,625,326,327,276,277,282,283,284,286,59,432,126,110,18,287,37,198,299,288,289,346,290,546,811,58,354,355,1023,528,1024,332,333,1020,63,64,1070,83,1048,1026,1027,453,120,1445,828,1025,31,0)) {}
       FIELD_SET(*this, FIX::MDEntryType);
+      FIELD_SET(*this, FIX::MDEntryID);
       FIELD_SET(*this, FIX::MDEntryPx);
+      FIELD_SET(*this, FIX::PriceType);
+      FIELD_SET(*this, FIX::YieldType);
+      FIELD_SET(*this, FIX::Yield);
+      FIELD_SET(*this, FIX::YieldCalcDate);
+      FIELD_SET(*this, FIX::YieldRedemptionDate);
+      FIELD_SET(*this, FIX::YieldRedemptionPrice);
+      FIELD_SET(*this, FIX::YieldRedemptionPriceType);
+      FIELD_SET(*this, FIX::Spread);
+      FIELD_SET(*this, FIX::BenchmarkCurveCurrency);
+      FIELD_SET(*this, FIX::BenchmarkCurveName);
+      FIELD_SET(*this, FIX::BenchmarkCurvePoint);
+      FIELD_SET(*this, FIX::BenchmarkPrice);
+      FIELD_SET(*this, FIX::BenchmarkPriceType);
+      FIELD_SET(*this, FIX::BenchmarkSecurityID);
+      FIELD_SET(*this, FIX::BenchmarkSecurityIDSource);
+      FIELD_SET(*this, FIX::OrdType);
       FIELD_SET(*this, FIX::Currency);
       FIELD_SET(*this, FIX::MDEntrySize);
+      FIELD_SET(*this, FIX::NoOfSecSizes);
+      class NoOfSecSizes: public FIX::Group
+      {
+      public:
+      NoOfSecSizes() : FIX::Group(1177,1178,FIX::message_order(1178,1179,0)) {}
+        FIELD_SET(*this, FIX::MDSecSizeType);
+        FIELD_SET(*this, FIX::MDSecSize);
+      };
+      FIELD_SET(*this, FIX::LotType);
       FIELD_SET(*this, FIX::MDEntryDate);
       FIELD_SET(*this, FIX::MDEntryTime);
       FIELD_SET(*this, FIX::TickDirection);
       FIELD_SET(*this, FIX::MDMkt);
       FIELD_SET(*this, FIX::TradingSessionID);
       FIELD_SET(*this, FIX::TradingSessionSubID);
+      FIELD_SET(*this, FIX::SecurityTradingStatus);
+      FIELD_SET(*this, FIX::HaltReasonInt);
       FIELD_SET(*this, FIX::QuoteCondition);
       FIELD_SET(*this, FIX::TradeCondition);
       FIELD_SET(*this, FIX::MDEntryOriginator);
@@ -262,6 +302,7 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::ExecInst);
       FIELD_SET(*this, FIX::SellerDays);
       FIELD_SET(*this, FIX::OrderID);
+      FIELD_SET(*this, FIX::SecondaryOrderID);
       FIELD_SET(*this, FIX::QuoteEntryID);
       FIELD_SET(*this, FIX::MDEntryBuyer);
       FIELD_SET(*this, FIX::MDEntrySeller);
@@ -285,7 +326,6 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::DealingCapacity);
       FIELD_SET(*this, FIX::MDEntrySpotRate);
       FIELD_SET(*this, FIX::MDEntryForwardPoints);
-      FIELD_SET(*this, FIX::MDEntryID);
       FIELD_SET(*this, FIX::NoPartyIDs);
       class NoPartyIDs: public FIX::Group
       {
@@ -303,34 +343,6 @@ namespace FIX50SP2
           FIELD_SET(*this, FIX::PartySubIDType);
         };
       };
-      FIELD_SET(*this, FIX::SecondaryOrderID);
-      FIELD_SET(*this, FIX::OrdType);
-      FIELD_SET(*this, FIX::PriceType);
-      FIELD_SET(*this, FIX::YieldType);
-      FIELD_SET(*this, FIX::Yield);
-      FIELD_SET(*this, FIX::YieldCalcDate);
-      FIELD_SET(*this, FIX::YieldRedemptionDate);
-      FIELD_SET(*this, FIX::YieldRedemptionPrice);
-      FIELD_SET(*this, FIX::YieldRedemptionPriceType);
-      FIELD_SET(*this, FIX::Spread);
-      FIELD_SET(*this, FIX::BenchmarkCurveCurrency);
-      FIELD_SET(*this, FIX::BenchmarkCurveName);
-      FIELD_SET(*this, FIX::BenchmarkCurvePoint);
-      FIELD_SET(*this, FIX::BenchmarkPrice);
-      FIELD_SET(*this, FIX::BenchmarkPriceType);
-      FIELD_SET(*this, FIX::BenchmarkSecurityID);
-      FIELD_SET(*this, FIX::BenchmarkSecurityIDSource);
-      FIELD_SET(*this, FIX::NoOfSecSizes);
-      class NoOfSecSizes: public FIX::Group
-      {
-      public:
-      NoOfSecSizes() : FIX::Group(1177,1178,FIX::message_order(1178,1179,0)) {}
-        FIELD_SET(*this, FIX::MDSecSizeType);
-        FIELD_SET(*this, FIX::MDSecSize);
-      };
-      FIELD_SET(*this, FIX::LotType);
-      FIELD_SET(*this, FIX::SecurityTradingStatus);
-      FIELD_SET(*this, FIX::HaltReasonInt);
       FIELD_SET(*this, FIX::SettlCurrency);
       FIELD_SET(*this, FIX::NoRateSources);
       class NoRateSources: public FIX::Group
@@ -347,11 +359,6 @@ namespace FIX50SP2
     };
     FIELD_SET(*this, FIX::ApplQueueDepth);
     FIELD_SET(*this, FIX::ApplQueueResolution);
-    FIELD_SET(*this, FIX::MDReportID);
-    FIELD_SET(*this, FIX::ClearingBusinessDate);
-    FIELD_SET(*this, FIX::MDBookType);
-    FIELD_SET(*this, FIX::MDFeedType);
-    FIELD_SET(*this, FIX::TradeDate);
     FIELD_SET(*this, FIX::NoRoutingIDs);
     class NoRoutingIDs: public FIX::Group
     {
@@ -360,14 +367,6 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::RoutingType);
       FIELD_SET(*this, FIX::RoutingID);
     };
-    FIELD_SET(*this, FIX::MDSubBookType);
-    FIELD_SET(*this, FIX::MarketDepth);
-    FIELD_SET(*this, FIX::TotNumReports);
-    FIELD_SET(*this, FIX::RefreshIndicator);
-    FIELD_SET(*this, FIX::ApplID);
-    FIELD_SET(*this, FIX::ApplSeqNum);
-    FIELD_SET(*this, FIX::ApplLastSeqNum);
-    FIELD_SET(*this, FIX::ApplResendFlag);
     FIELD_SET(*this, FIX::MDStreamID);
   };
 
