@@ -1,7 +1,7 @@
 /* -*- C++ -*- */
  
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -19,14 +19,16 @@
 **
 ****************************************************************************/
 
-#ifndef FIX50_MESSAGECRACKER_H
-#define FIX50_MESSAGECRACKER_H
+#ifndef FIX50SP2_MESSAGECRACKER_H
+#define FIX50SP2_MESSAGECRACKER_H
+
 
 #include "../SessionID.h"
 #include "../Exceptions.h"
-#include "../fix50/Message.h"
 
-namespace FIX50
+#include "../fix50sp2/Message.h"
+
+namespace FIX50SP2
 {  
   class IOI; 
   class Advertisement; 
@@ -135,9 +137,7 @@ namespace FIX50
   class UserNotification; 
   class StreamAssignmentRequest; 
   class StreamAssignmentReport; 
-  class StreamAssignmentReportACK; 
-  class PartyDetailsListRequest; 
-  class PartyDetailsListReport;
+  class StreamAssignmentReportACK;
 
   class MessageCracker
   {
@@ -363,10 +363,6 @@ namespace FIX50
     { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( const StreamAssignmentReportACK&, const FIX::SessionID& ) 
     { throw FIX::UnsupportedMessageType(); }
-  virtual void onMessage( const PartyDetailsListRequest&, const FIX::SessionID& ) 
-    { throw FIX::UnsupportedMessageType(); }
-  virtual void onMessage( const PartyDetailsListReport&, const FIX::SessionID& ) 
-    { throw FIX::UnsupportedMessageType(); }
   virtual void onMessage( IOI&, const FIX::SessionID& ) {} 
  virtual void onMessage( Advertisement&, const FIX::SessionID& ) {} 
  virtual void onMessage( ExecutionReport&, const FIX::SessionID& ) {} 
@@ -475,8 +471,6 @@ namespace FIX50
  virtual void onMessage( StreamAssignmentRequest&, const FIX::SessionID& ) {} 
  virtual void onMessage( StreamAssignmentReport&, const FIX::SessionID& ) {} 
  virtual void onMessage( StreamAssignmentReportACK&, const FIX::SessionID& ) {} 
- virtual void onMessage( PartyDetailsListRequest&, const FIX::SessionID& ) {} 
- virtual void onMessage( PartyDetailsListReport&, const FIX::SessionID& ) {} 
 
 public:
   void crack( const Message& message, 
@@ -808,12 +802,6 @@ public:
     else
     if( msgTypeValue == "CE" )
       onMessage( (const StreamAssignmentReportACK&)message, sessionID );
-    else
-    if( msgTypeValue == "CF" )
-      onMessage( (const PartyDetailsListRequest&)message, sessionID );
-    else
-    if( msgTypeValue == "CG" )
-      onMessage( (const PartyDetailsListReport&)message, sessionID );
     else onMessage( message, sessionID );
   }
   
@@ -1147,16 +1135,10 @@ void crack( Message& message,
     else
     if( msgTypeValue == "CE" )
       onMessage( (StreamAssignmentReportACK&)message, sessionID );
-    else
-    if( msgTypeValue == "CF" )
-      onMessage( (PartyDetailsListRequest&)message, sessionID );
-    else
-    if( msgTypeValue == "CG" )
-      onMessage( (PartyDetailsListReport&)message, sessionID );
     else onMessage( message, sessionID );
   }
 
   };
 }
 
-#endif //FIX50_MESSAGECRACKER_H
+#endif
