@@ -27,21 +27,47 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::QuoteReqID);
     FIELD_SET(*this, FIX::RFQReqID);
     FIELD_SET(*this, FIX::QuoteRequestRejectReason);
+    FIELD_SET(*this, FIX::PrivateQuote);
+    FIELD_SET(*this, FIX::RespondentType);
+    FIELD_SET(*this, FIX::PreTradeAnonymity);
+    FIELD_SET(*this, FIX::NoRootPartyIDs);
+    class NoRootPartyIDs: public FIX::Group
+    {
+    public:
+    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
+      FIELD_SET(*this, FIX::RootPartyID);
+      FIELD_SET(*this, FIX::RootPartyIDSource);
+      FIELD_SET(*this, FIX::RootPartyRole);
+      FIELD_SET(*this, FIX::NoRootPartySubIDs);
+      class NoRootPartySubIDs: public FIX::Group
+      {
+      public:
+      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
+        FIELD_SET(*this, FIX::RootPartySubID);
+        FIELD_SET(*this, FIX::RootPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::NoRelatedSym);
     class NoRelatedSym: public FIX::Group
     {
     public:
-    NoRelatedSym() : FIX::Group(146,55,FIX::message_order(55,65,48,22,460,461,167,762,200,541,224,225,239,226,227,228,255,543,470,471,472,240,202,947,206,231,223,207,106,348,349,107,350,351,691,667,875,876,873,874,965,966,1049,967,968,969,970,971,996,997,1079,1151,1146,1147,1227,1191,1192,1193,1194,1195,1196,1198,1199,1200,201,1244,1242,1197,1435,1439,1449,1450,1451,1452,1457,1458,1478,1479,1480,1481,1482,913,914,915,918,788,916,917,919,898,711,140,303,537,336,625,229,54,854,38,152,516,468,469,63,64,193,192,15,232,1,660,581,555,735,692,40,126,60,218,220,221,222,662,663,699,761,423,44,640,235,236,701,696,697,698,453,0)) {}
+    NoRelatedSym() : FIX::Group(146,55,FIX::message_order(55,65,48,22,460,1227,1151,461,167,762,200,541,1079,966,1049,965,224,225,239,226,227,228,255,543,470,471,472,240,202,947,967,968,206,231,969,1146,996,1147,1191,1192,1193,1194,1195,1196,1197,1198,1199,1200,201,1244,1242,997,223,207,970,971,106,348,349,107,350,351,691,667,875,876,873,874,1435,1439,1449,1450,1451,1452,1457,1458,1478,1479,1480,1481,1482,913,914,915,918,788,916,917,919,898,711,140,303,537,336,625,229,54,854,38,152,516,468,469,63,64,193,192,15,232,1,660,581,555,735,692,40,126,60,218,220,221,222,662,663,699,761,423,44,640,235,236,701,696,697,698,453,0)) {}
       FIELD_SET(*this, FIX::Symbol);
       FIELD_SET(*this, FIX::SymbolSfx);
       FIELD_SET(*this, FIX::SecurityID);
       FIELD_SET(*this, FIX::SecurityIDSource);
       FIELD_SET(*this, FIX::Product);
+      FIELD_SET(*this, FIX::ProductComplex);
+      FIELD_SET(*this, FIX::SecurityGroup);
       FIELD_SET(*this, FIX::CFICode);
       FIELD_SET(*this, FIX::SecurityType);
       FIELD_SET(*this, FIX::SecuritySubType);
       FIELD_SET(*this, FIX::MaturityMonthYear);
       FIELD_SET(*this, FIX::MaturityDate);
+      FIELD_SET(*this, FIX::MaturityTime);
+      FIELD_SET(*this, FIX::SettleOnOpenFlag);
+      FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+      FIELD_SET(*this, FIX::SecurityStatus);
       FIELD_SET(*this, FIX::CouponPaymentDate);
       FIELD_SET(*this, FIX::IssueDate);
       FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -56,10 +82,32 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::RedemptionDate);
       FIELD_SET(*this, FIX::StrikePrice);
       FIELD_SET(*this, FIX::StrikeCurrency);
+      FIELD_SET(*this, FIX::StrikeMultiplier);
+      FIELD_SET(*this, FIX::StrikeValue);
       FIELD_SET(*this, FIX::OptAttribute);
       FIELD_SET(*this, FIX::ContractMultiplier);
+      FIELD_SET(*this, FIX::MinPriceIncrement);
+      FIELD_SET(*this, FIX::MinPriceIncrementAmount);
+      FIELD_SET(*this, FIX::UnitOfMeasure);
+      FIELD_SET(*this, FIX::UnitOfMeasureQty);
+      FIELD_SET(*this, FIX::PriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::SettlMethod);
+      FIELD_SET(*this, FIX::ExerciseStyle);
+      FIELD_SET(*this, FIX::OptPayoutAmount);
+      FIELD_SET(*this, FIX::PriceQuoteMethod);
+      FIELD_SET(*this, FIX::ValuationMethod);
+      FIELD_SET(*this, FIX::ListMethod);
+      FIELD_SET(*this, FIX::CapPrice);
+      FIELD_SET(*this, FIX::FloorPrice);
+      FIELD_SET(*this, FIX::PutOrCall);
+      FIELD_SET(*this, FIX::FlexibleIndicator);
+      FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
+      FIELD_SET(*this, FIX::TimeUnit);
       FIELD_SET(*this, FIX::CouponRate);
       FIELD_SET(*this, FIX::SecurityExchange);
+      FIELD_SET(*this, FIX::PositionLimit);
+      FIELD_SET(*this, FIX::NTPositionLimit);
       FIELD_SET(*this, FIX::Issuer);
       FIELD_SET(*this, FIX::EncodedIssuerLen);
       FIELD_SET(*this, FIX::EncodedIssuer);
@@ -72,34 +120,6 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::CPRegType);
       FIELD_SET(*this, FIX::DatedDate);
       FIELD_SET(*this, FIX::InterestAccrualDate);
-      FIELD_SET(*this, FIX::SecurityStatus);
-      FIELD_SET(*this, FIX::SettleOnOpenFlag);
-      FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-      FIELD_SET(*this, FIX::StrikeMultiplier);
-      FIELD_SET(*this, FIX::StrikeValue);
-      FIELD_SET(*this, FIX::MinPriceIncrement);
-      FIELD_SET(*this, FIX::PositionLimit);
-      FIELD_SET(*this, FIX::NTPositionLimit);
-      FIELD_SET(*this, FIX::UnitOfMeasure);
-      FIELD_SET(*this, FIX::TimeUnit);
-      FIELD_SET(*this, FIX::MaturityTime);
-      FIELD_SET(*this, FIX::SecurityGroup);
-      FIELD_SET(*this, FIX::MinPriceIncrementAmount);
-      FIELD_SET(*this, FIX::UnitOfMeasureQty);
-      FIELD_SET(*this, FIX::ProductComplex);
-      FIELD_SET(*this, FIX::PriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::SettlMethod);
-      FIELD_SET(*this, FIX::ExerciseStyle);
-      FIELD_SET(*this, FIX::OptPayoutAmount);
-      FIELD_SET(*this, FIX::PriceQuoteMethod);
-      FIELD_SET(*this, FIX::ListMethod);
-      FIELD_SET(*this, FIX::CapPrice);
-      FIELD_SET(*this, FIX::FloorPrice);
-      FIELD_SET(*this, FIX::PutOrCall);
-      FIELD_SET(*this, FIX::FlexibleIndicator);
-      FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
-      FIELD_SET(*this, FIX::ValuationMethod);
       FIELD_SET(*this, FIX::ContractMultiplierUnit);
       FIELD_SET(*this, FIX::FlowScheduleType);
       FIELD_SET(*this, FIX::RestructuringType);
@@ -126,7 +146,7 @@ namespace FIX50SP2
       class NoUnderlyings: public FIX::Group
       {
       public:
-      NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,1213,315,1419,1423,1424,1425,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
+      NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,1213,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1423,1424,1425,1000,1419,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,315,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
         FIELD_SET(*this, FIX::UnderlyingSymbol);
         FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
         FIELD_SET(*this, FIX::UnderlyingSecurityID);
@@ -137,6 +157,7 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
         FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
         FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+        FIELD_SET(*this, FIX::UnderlyingMaturityTime);
         FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
         FIELD_SET(*this, FIX::UnderlyingIssueDate);
         FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
@@ -153,6 +174,12 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
         FIELD_SET(*this, FIX::UnderlyingOptAttribute);
         FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
+        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+        FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
         FIELD_SET(*this, FIX::UnderlyingCouponRate);
         FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
         FIELD_SET(*this, FIX::UnderlyingIssuer);
@@ -163,31 +190,24 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
         FIELD_SET(*this, FIX::UnderlyingCPProgram);
         FIELD_SET(*this, FIX::UnderlyingCPRegType);
+        FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
         FIELD_SET(*this, FIX::UnderlyingCurrency);
         FIELD_SET(*this, FIX::UnderlyingQty);
+        FIELD_SET(*this, FIX::UnderlyingSettlementType);
+        FIELD_SET(*this, FIX::UnderlyingCashAmount);
+        FIELD_SET(*this, FIX::UnderlyingCashType);
         FIELD_SET(*this, FIX::UnderlyingPx);
         FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
         FIELD_SET(*this, FIX::UnderlyingEndPrice);
         FIELD_SET(*this, FIX::UnderlyingStartValue);
         FIELD_SET(*this, FIX::UnderlyingCurrentValue);
         FIELD_SET(*this, FIX::UnderlyingEndValue);
-        FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-        FIELD_SET(*this, FIX::UnderlyingSettlementType);
-        FIELD_SET(*this, FIX::UnderlyingCashAmount);
-        FIELD_SET(*this, FIX::UnderlyingCashType);
-        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-        FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-        FIELD_SET(*this, FIX::UnderlyingCapValue);
-        FIELD_SET(*this, FIX::UnderlyingSettlMethod);
         FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
         FIELD_SET(*this, FIX::UnderlyingFXRate);
         FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-        FIELD_SET(*this, FIX::UnderlyingMaturityTime);
+        FIELD_SET(*this, FIX::UnderlyingCapValue);
+        FIELD_SET(*this, FIX::UnderlyingSettlMethod);
         FIELD_SET(*this, FIX::UnderlyingPutOrCall);
-        FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
-        FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
-        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
-        FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
         FIELD_SET(*this, FIX::UnderlyingContractMultiplierUnit);
         FIELD_SET(*this, FIX::UnderlyingFlowScheduleType);
         FIELD_SET(*this, FIX::UnderlyingRestructuringType);
@@ -230,7 +250,7 @@ namespace FIX50SP2
       class NoLegs: public FIX::Group
       {
       public:
-      NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,1017,566,1212,1358,1420,1224,1421,1422,1436,1440,687,690,587,588,683,539,676,677,678,679,680,685,654,0)) {}
+      NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,1212,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1224,1421,1422,1001,1420,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1358,1017,1436,1440,687,685,690,587,588,683,539,676,677,678,679,680,654,0)) {}
         FIELD_SET(*this, FIX::LegSymbol);
         FIELD_SET(*this, FIX::LegSymbolSfx);
         FIELD_SET(*this, FIX::LegSecurityID);
@@ -241,6 +261,7 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegSecuritySubType);
         FIELD_SET(*this, FIX::LegMaturityMonthYear);
         FIELD_SET(*this, FIX::LegMaturityDate);
+        FIELD_SET(*this, FIX::LegMaturityTime);
         FIELD_SET(*this, FIX::LegCouponPaymentDate);
         FIELD_SET(*this, FIX::LegIssueDate);
         FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
@@ -257,6 +278,12 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegStrikeCurrency);
         FIELD_SET(*this, FIX::LegOptAttribute);
         FIELD_SET(*this, FIX::LegContractMultiplier);
+        FIELD_SET(*this, FIX::LegUnitOfMeasure);
+        FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
+        FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegTimeUnit);
+        FIELD_SET(*this, FIX::LegExerciseStyle);
         FIELD_SET(*this, FIX::LegCouponRate);
         FIELD_SET(*this, FIX::LegSecurityExchange);
         FIELD_SET(*this, FIX::LegIssuer);
@@ -272,19 +299,12 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegDatedDate);
         FIELD_SET(*this, FIX::LegContractSettlMonth);
         FIELD_SET(*this, FIX::LegInterestAccrualDate);
-        FIELD_SET(*this, FIX::LegUnitOfMeasure);
-        FIELD_SET(*this, FIX::LegTimeUnit);
-        FIELD_SET(*this, FIX::LegOptionRatio);
-        FIELD_SET(*this, FIX::LegPrice);
-        FIELD_SET(*this, FIX::LegMaturityTime);
         FIELD_SET(*this, FIX::LegPutOrCall);
-        FIELD_SET(*this, FIX::LegExerciseStyle);
-        FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
-        FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
-        FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+        FIELD_SET(*this, FIX::LegOptionRatio);
         FIELD_SET(*this, FIX::LegContractMultiplierUnit);
         FIELD_SET(*this, FIX::LegFlowScheduleType);
         FIELD_SET(*this, FIX::LegQty);
+        FIELD_SET(*this, FIX::LegOrderQty);
         FIELD_SET(*this, FIX::LegSwapType);
         FIELD_SET(*this, FIX::LegSettlType);
         FIELD_SET(*this, FIX::LegSettlDate);
@@ -318,7 +338,6 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::LegBenchmarkCurvePoint);
         FIELD_SET(*this, FIX::LegBenchmarkPrice);
         FIELD_SET(*this, FIX::LegBenchmarkPriceType);
-        FIELD_SET(*this, FIX::LegOrderQty);
         FIELD_SET(*this, FIX::LegRefID);
       };
       FIELD_SET(*this, FIX::NoQuoteQualifiers);
@@ -370,26 +389,6 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::Text);
     FIELD_SET(*this, FIX::EncodedTextLen);
     FIELD_SET(*this, FIX::EncodedText);
-    FIELD_SET(*this, FIX::NoRootPartyIDs);
-    class NoRootPartyIDs: public FIX::Group
-    {
-    public:
-    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
-      FIELD_SET(*this, FIX::RootPartyID);
-      FIELD_SET(*this, FIX::RootPartyIDSource);
-      FIELD_SET(*this, FIX::RootPartyRole);
-      FIELD_SET(*this, FIX::NoRootPartySubIDs);
-      class NoRootPartySubIDs: public FIX::Group
-      {
-      public:
-      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
-        FIELD_SET(*this, FIX::RootPartySubID);
-        FIELD_SET(*this, FIX::RootPartySubIDType);
-      };
-    };
-    FIELD_SET(*this, FIX::PrivateQuote);
-    FIELD_SET(*this, FIX::RespondentType);
-    FIELD_SET(*this, FIX::PreTradeAnonymity);
   };
 
 }
