@@ -16,12 +16,38 @@ namespace FIX50SP2
     static FIX::MsgType MsgType() { return FIX::MsgType("AR"); }
 
     FIELD_SET(*this, FIX::TradeReportID);
+    FIELD_SET(*this, FIX::TradeID);
+    FIELD_SET(*this, FIX::SecondaryTradeID);
+    FIELD_SET(*this, FIX::FirmTradeID);
+    FIELD_SET(*this, FIX::SecondaryFirmTradeID);
     FIELD_SET(*this, FIX::TradeReportTransType);
     FIELD_SET(*this, FIX::TradeReportType);
     FIELD_SET(*this, FIX::TrdType);
     FIELD_SET(*this, FIX::TrdSubType);
     FIELD_SET(*this, FIX::SecondaryTrdType);
+    FIELD_SET(*this, FIX::TradeHandlingInstr);
+    FIELD_SET(*this, FIX::OrigTradeHandlingInstr);
+    FIELD_SET(*this, FIX::OrigTradeDate);
+    FIELD_SET(*this, FIX::OrigTradeID);
+    FIELD_SET(*this, FIX::OrigSecondaryTradeID);
     FIELD_SET(*this, FIX::TransferReason);
+    FIELD_SET(*this, FIX::NoRootPartyIDs);
+    class NoRootPartyIDs: public FIX::Group
+    {
+    public:
+    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
+      FIELD_SET(*this, FIX::RootPartyID);
+      FIELD_SET(*this, FIX::RootPartyIDSource);
+      FIELD_SET(*this, FIX::RootPartyRole);
+      FIELD_SET(*this, FIX::NoRootPartySubIDs);
+      class NoRootPartySubIDs: public FIX::Group
+      {
+      public:
+      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
+        FIELD_SET(*this, FIX::RootPartySubID);
+        FIELD_SET(*this, FIX::RootPartySubIDType);
+      };
+    };
     FIELD_SET(*this, FIX::ExecType);
     FIELD_SET(*this, FIX::TradeReportRefID);
     FIELD_SET(*this, FIX::SecondaryTradeReportRefID);
@@ -33,16 +59,32 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::TrdMatchID);
     FIELD_SET(*this, FIX::ExecID);
     FIELD_SET(*this, FIX::SecondaryExecID);
+    FIELD_SET(*this, FIX::ExecRestatementReason);
+    FIELD_SET(*this, FIX::PreviouslyReported);
+    FIELD_SET(*this, FIX::PriceType);
+    FIELD_SET(*this, FIX::UnderlyingTradingSessionID);
+    FIELD_SET(*this, FIX::UnderlyingTradingSessionSubID);
+    FIELD_SET(*this, FIX::SettlSessID);
+    FIELD_SET(*this, FIX::SettlSessSubID);
+    FIELD_SET(*this, FIX::QtyType);
+    FIELD_SET(*this, FIX::LastQty);
+    FIELD_SET(*this, FIX::LastPx);
     FIELD_SET(*this, FIX::Symbol);
     FIELD_SET(*this, FIX::SymbolSfx);
     FIELD_SET(*this, FIX::SecurityID);
     FIELD_SET(*this, FIX::SecurityIDSource);
     FIELD_SET(*this, FIX::Product);
+    FIELD_SET(*this, FIX::ProductComplex);
+    FIELD_SET(*this, FIX::SecurityGroup);
     FIELD_SET(*this, FIX::CFICode);
     FIELD_SET(*this, FIX::SecurityType);
     FIELD_SET(*this, FIX::SecuritySubType);
     FIELD_SET(*this, FIX::MaturityMonthYear);
     FIELD_SET(*this, FIX::MaturityDate);
+    FIELD_SET(*this, FIX::MaturityTime);
+    FIELD_SET(*this, FIX::SettleOnOpenFlag);
+    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
+    FIELD_SET(*this, FIX::SecurityStatus);
     FIELD_SET(*this, FIX::CouponPaymentDate);
     FIELD_SET(*this, FIX::IssueDate);
     FIELD_SET(*this, FIX::RepoCollateralSecurityType);
@@ -57,10 +99,32 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::RedemptionDate);
     FIELD_SET(*this, FIX::StrikePrice);
     FIELD_SET(*this, FIX::StrikeCurrency);
+    FIELD_SET(*this, FIX::StrikeMultiplier);
+    FIELD_SET(*this, FIX::StrikeValue);
     FIELD_SET(*this, FIX::OptAttribute);
     FIELD_SET(*this, FIX::ContractMultiplier);
+    FIELD_SET(*this, FIX::MinPriceIncrement);
+    FIELD_SET(*this, FIX::MinPriceIncrementAmount);
+    FIELD_SET(*this, FIX::UnitOfMeasure);
+    FIELD_SET(*this, FIX::UnitOfMeasureQty);
+    FIELD_SET(*this, FIX::PriceUnitOfMeasure);
+    FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
+    FIELD_SET(*this, FIX::SettlMethod);
+    FIELD_SET(*this, FIX::ExerciseStyle);
+    FIELD_SET(*this, FIX::OptPayoutAmount);
+    FIELD_SET(*this, FIX::PriceQuoteMethod);
+    FIELD_SET(*this, FIX::ValuationMethod);
+    FIELD_SET(*this, FIX::ListMethod);
+    FIELD_SET(*this, FIX::CapPrice);
+    FIELD_SET(*this, FIX::FloorPrice);
+    FIELD_SET(*this, FIX::PutOrCall);
+    FIELD_SET(*this, FIX::FlexibleIndicator);
+    FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
+    FIELD_SET(*this, FIX::TimeUnit);
     FIELD_SET(*this, FIX::CouponRate);
     FIELD_SET(*this, FIX::SecurityExchange);
+    FIELD_SET(*this, FIX::PositionLimit);
+    FIELD_SET(*this, FIX::NTPositionLimit);
     FIELD_SET(*this, FIX::Issuer);
     FIELD_SET(*this, FIX::EncodedIssuerLen);
     FIELD_SET(*this, FIX::EncodedIssuer);
@@ -73,34 +137,6 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::CPRegType);
     FIELD_SET(*this, FIX::DatedDate);
     FIELD_SET(*this, FIX::InterestAccrualDate);
-    FIELD_SET(*this, FIX::SecurityStatus);
-    FIELD_SET(*this, FIX::SettleOnOpenFlag);
-    FIELD_SET(*this, FIX::InstrmtAssignmentMethod);
-    FIELD_SET(*this, FIX::StrikeMultiplier);
-    FIELD_SET(*this, FIX::StrikeValue);
-    FIELD_SET(*this, FIX::MinPriceIncrement);
-    FIELD_SET(*this, FIX::PositionLimit);
-    FIELD_SET(*this, FIX::NTPositionLimit);
-    FIELD_SET(*this, FIX::UnitOfMeasure);
-    FIELD_SET(*this, FIX::TimeUnit);
-    FIELD_SET(*this, FIX::MaturityTime);
-    FIELD_SET(*this, FIX::SecurityGroup);
-    FIELD_SET(*this, FIX::MinPriceIncrementAmount);
-    FIELD_SET(*this, FIX::UnitOfMeasureQty);
-    FIELD_SET(*this, FIX::ProductComplex);
-    FIELD_SET(*this, FIX::PriceUnitOfMeasure);
-    FIELD_SET(*this, FIX::PriceUnitOfMeasureQty);
-    FIELD_SET(*this, FIX::SettlMethod);
-    FIELD_SET(*this, FIX::ExerciseStyle);
-    FIELD_SET(*this, FIX::OptPayoutAmount);
-    FIELD_SET(*this, FIX::PriceQuoteMethod);
-    FIELD_SET(*this, FIX::ListMethod);
-    FIELD_SET(*this, FIX::CapPrice);
-    FIELD_SET(*this, FIX::FloorPrice);
-    FIELD_SET(*this, FIX::PutOrCall);
-    FIELD_SET(*this, FIX::FlexibleIndicator);
-    FIELD_SET(*this, FIX::FlexProductEligibilityIndicator);
-    FIELD_SET(*this, FIX::ValuationMethod);
     FIELD_SET(*this, FIX::ContractMultiplierUnit);
     FIELD_SET(*this, FIX::FlowScheduleType);
     FIELD_SET(*this, FIX::RestructuringType);
@@ -114,29 +150,116 @@ namespace FIX50SP2
     FIELD_SET(*this, FIX::StrikePriceBoundaryPrecision);
     FIELD_SET(*this, FIX::UnderlyingPriceDeterminationMethod);
     FIELD_SET(*this, FIX::OptPayoutType);
+    FIELD_SET(*this, FIX::LastParPx);
+    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
+    FIELD_SET(*this, FIX::LastSwapPoints);
+    FIELD_SET(*this, FIX::Currency);
+    FIELD_SET(*this, FIX::SettlCurrency);
+    FIELD_SET(*this, FIX::LastSpotRate);
+    FIELD_SET(*this, FIX::LastForwardPoints);
+    FIELD_SET(*this, FIX::LastMkt);
+    FIELD_SET(*this, FIX::TradeDate);
+    FIELD_SET(*this, FIX::ClearingBusinessDate);
+    FIELD_SET(*this, FIX::AvgPx);
+    FIELD_SET(*this, FIX::AvgPxIndicator);
+    FIELD_SET(*this, FIX::MultiLegReportingType);
+    FIELD_SET(*this, FIX::TradeLegRefID);
     FIELD_SET(*this, FIX::TransactTime);
-    FIELD_SET(*this, FIX::NoTrdRegTimestamps);
-    class NoTrdRegTimestamps: public FIX::Group
+    FIELD_SET(*this, FIX::SettlType);
+    FIELD_SET(*this, FIX::NoUnderlyings);
+    class NoUnderlyings: public FIX::Group
     {
     public:
-    NoTrdRegTimestamps() : FIX::Group(768,769,FIX::message_order(769,770,771,1033,1034,1035,0)) {}
-      FIELD_SET(*this, FIX::TrdRegTimestamp);
-      FIELD_SET(*this, FIX::TrdRegTimestampType);
-      FIELD_SET(*this, FIX::TrdRegTimestampOrigin);
-      FIELD_SET(*this, FIX::DeskType);
-      FIELD_SET(*this, FIX::DeskTypeSource);
-      FIELD_SET(*this, FIX::DeskOrderHandlingInst);
+    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,1213,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,998,1423,1424,1425,1000,1419,435,308,306,362,363,307,364,365,877,878,972,318,879,975,973,974,810,882,883,884,885,886,1044,1045,1046,1038,1039,315,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
+      FIELD_SET(*this, FIX::UnderlyingSymbol);
+      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
+      FIELD_SET(*this, FIX::UnderlyingSecurityID);
+      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
+      FIELD_SET(*this, FIX::UnderlyingProduct);
+      FIELD_SET(*this, FIX::UnderlyingCFICode);
+      FIELD_SET(*this, FIX::UnderlyingSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
+      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
+      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
+      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
+      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
+      FIELD_SET(*this, FIX::UnderlyingIssueDate);
+      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
+      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
+      FIELD_SET(*this, FIX::UnderlyingFactor);
+      FIELD_SET(*this, FIX::UnderlyingCreditRating);
+      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
+      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
+      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
+      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
+      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
+      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
+      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
+      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
+      FIELD_SET(*this, FIX::UnderlyingCouponRate);
+      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
+      FIELD_SET(*this, FIX::UnderlyingIssuer);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
+      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
+      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
+      FIELD_SET(*this, FIX::UnderlyingCPProgram);
+      FIELD_SET(*this, FIX::UnderlyingCPRegType);
+      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
+      FIELD_SET(*this, FIX::UnderlyingCurrency);
+      FIELD_SET(*this, FIX::UnderlyingQty);
+      FIELD_SET(*this, FIX::UnderlyingSettlementType);
+      FIELD_SET(*this, FIX::UnderlyingCashAmount);
+      FIELD_SET(*this, FIX::UnderlyingCashType);
+      FIELD_SET(*this, FIX::UnderlyingPx);
+      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
+      FIELD_SET(*this, FIX::UnderlyingEndPrice);
+      FIELD_SET(*this, FIX::UnderlyingStartValue);
+      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
+      FIELD_SET(*this, FIX::UnderlyingEndValue);
+      FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
+      FIELD_SET(*this, FIX::UnderlyingFXRate);
+      FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
+      FIELD_SET(*this, FIX::UnderlyingCapValue);
+      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
+      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
+      FIELD_SET(*this, FIX::UnderlyingContractMultiplierUnit);
+      FIELD_SET(*this, FIX::UnderlyingFlowScheduleType);
+      FIELD_SET(*this, FIX::UnderlyingRestructuringType);
+      FIELD_SET(*this, FIX::UnderlyingSeniority);
+      FIELD_SET(*this, FIX::UnderlyingNotionalPercentageOutstanding);
+      FIELD_SET(*this, FIX::UnderlyingOriginalNotionalPercentageOutstanding);
+      FIELD_SET(*this, FIX::UnderlyingAttachmentPoint);
+      FIELD_SET(*this, FIX::UnderlyingDetachmentPoint);
     };
-    FIELD_SET(*this, FIX::ResponseTransportType);
-    FIELD_SET(*this, FIX::ResponseDestination);
-    FIELD_SET(*this, FIX::Text);
-    FIELD_SET(*this, FIX::EncodedTextLen);
-    FIELD_SET(*this, FIX::EncodedText);
+    FIELD_SET(*this, FIX::MatchStatus);
+    FIELD_SET(*this, FIX::MatchType);
+    FIELD_SET(*this, FIX::CopyMsgIndicator);
+    FIELD_SET(*this, FIX::NoTrdRepIndicators);
+    class NoTrdRepIndicators: public FIX::Group
+    {
+    public:
+    NoTrdRepIndicators() : FIX::Group(1387,1388,FIX::message_order(1388,1389,0)) {}
+      FIELD_SET(*this, FIX::TrdRepPartyRole);
+      FIELD_SET(*this, FIX::TrdRepIndicator);
+    };
+    FIELD_SET(*this, FIX::PublishTrdIndicator);
+    FIELD_SET(*this, FIX::TradePublishIndicator);
+    FIELD_SET(*this, FIX::ShortSaleReason);
     FIELD_SET(*this, FIX::NoLegs);
     class NoLegs: public FIX::Group
     {
     public:
-    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,999,1001,1017,566,1212,1358,1420,1224,1421,1422,1436,1440,687,690,683,564,565,539,654,587,588,637,990,675,1073,1074,1075,1152,1342,1379,1381,1383,1384,1418,0)) {}
+    NoLegs() : FIX::Group(555,600,FIX::message_order(600,601,602,603,607,608,609,764,610,611,1212,248,249,250,251,252,253,257,599,596,597,598,254,612,942,613,614,999,1224,1421,1422,1001,1420,615,616,617,618,619,620,621,622,623,624,556,740,739,955,956,1358,1017,1436,1440,687,690,990,1152,683,564,565,539,654,587,588,637,675,1073,1074,1075,1379,1381,1383,1384,1418,1342,0)) {}
       FIELD_SET(*this, FIX::LegSymbol);
       FIELD_SET(*this, FIX::LegSymbolSfx);
       FIELD_SET(*this, FIX::LegSecurityID);
@@ -147,6 +270,7 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegSecuritySubType);
       FIELD_SET(*this, FIX::LegMaturityMonthYear);
       FIELD_SET(*this, FIX::LegMaturityDate);
+      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegCouponPaymentDate);
       FIELD_SET(*this, FIX::LegIssueDate);
       FIELD_SET(*this, FIX::LegRepoCollateralSecurityType);
@@ -163,6 +287,12 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegStrikeCurrency);
       FIELD_SET(*this, FIX::LegOptAttribute);
       FIELD_SET(*this, FIX::LegContractMultiplier);
+      FIELD_SET(*this, FIX::LegUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
+      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegTimeUnit);
+      FIELD_SET(*this, FIX::LegExerciseStyle);
       FIELD_SET(*this, FIX::LegCouponRate);
       FIELD_SET(*this, FIX::LegSecurityExchange);
       FIELD_SET(*this, FIX::LegIssuer);
@@ -178,20 +308,14 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegDatedDate);
       FIELD_SET(*this, FIX::LegContractSettlMonth);
       FIELD_SET(*this, FIX::LegInterestAccrualDate);
-      FIELD_SET(*this, FIX::LegUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegTimeUnit);
-      FIELD_SET(*this, FIX::LegOptionRatio);
-      FIELD_SET(*this, FIX::LegPrice);
-      FIELD_SET(*this, FIX::LegMaturityTime);
       FIELD_SET(*this, FIX::LegPutOrCall);
-      FIELD_SET(*this, FIX::LegExerciseStyle);
-      FIELD_SET(*this, FIX::LegUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::LegPriceUnitOfMeasureQty);
+      FIELD_SET(*this, FIX::LegOptionRatio);
       FIELD_SET(*this, FIX::LegContractMultiplierUnit);
       FIELD_SET(*this, FIX::LegFlowScheduleType);
       FIELD_SET(*this, FIX::LegQty);
       FIELD_SET(*this, FIX::LegSwapType);
+      FIELD_SET(*this, FIX::LegReportID);
+      FIELD_SET(*this, FIX::LegNumber);
       FIELD_SET(*this, FIX::NoLegStipulations);
       class NoLegStipulations: public FIX::Group
       {
@@ -223,12 +347,15 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::LegSettlType);
       FIELD_SET(*this, FIX::LegSettlDate);
       FIELD_SET(*this, FIX::LegLastPx);
-      FIELD_SET(*this, FIX::LegReportID);
       FIELD_SET(*this, FIX::LegSettlCurrency);
       FIELD_SET(*this, FIX::LegLastForwardPoints);
       FIELD_SET(*this, FIX::LegCalculatedCcyLastQty);
       FIELD_SET(*this, FIX::LegGrossTradeAmt);
-      FIELD_SET(*this, FIX::LegNumber);
+      FIELD_SET(*this, FIX::LegVolatility);
+      FIELD_SET(*this, FIX::LegDividendYield);
+      FIELD_SET(*this, FIX::LegCurrencyRatio);
+      FIELD_SET(*this, FIX::LegExecInst);
+      FIELD_SET(*this, FIX::LegLastQty);
       FIELD_SET(*this, FIX::NoOfLegUnderlyings);
       class NoOfLegUnderlyings: public FIX::Group
       {
@@ -250,40 +377,26 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::UnderlyingLegSecurityExchange);
         FIELD_SET(*this, FIX::UnderlyingLegSecurityDesc);
       };
-      FIELD_SET(*this, FIX::LegVolatility);
-      FIELD_SET(*this, FIX::LegDividendYield);
-      FIELD_SET(*this, FIX::LegCurrencyRatio);
-      FIELD_SET(*this, FIX::LegExecInst);
-      FIELD_SET(*this, FIX::LegLastQty);
     };
+    FIELD_SET(*this, FIX::NoTrdRegTimestamps);
+    class NoTrdRegTimestamps: public FIX::Group
+    {
+    public:
+    NoTrdRegTimestamps() : FIX::Group(768,769,FIX::message_order(769,770,771,1033,1034,1035,0)) {}
+      FIELD_SET(*this, FIX::TrdRegTimestamp);
+      FIELD_SET(*this, FIX::TrdRegTimestampType);
+      FIELD_SET(*this, FIX::TrdRegTimestampOrigin);
+      FIELD_SET(*this, FIX::DeskType);
+      FIELD_SET(*this, FIX::DeskTypeSource);
+      FIELD_SET(*this, FIX::DeskOrderHandlingInst);
+    };
+    FIELD_SET(*this, FIX::ResponseTransportType);
+    FIELD_SET(*this, FIX::ResponseDestination);
+    FIELD_SET(*this, FIX::Text);
+    FIELD_SET(*this, FIX::EncodedTextLen);
+    FIELD_SET(*this, FIX::EncodedText);
+    FIELD_SET(*this, FIX::AsOfIndicator);
     FIELD_SET(*this, FIX::ClearingFeeIndicator);
-    FIELD_SET(*this, FIX::ExecRestatementReason);
-    FIELD_SET(*this, FIX::PreviouslyReported);
-    FIELD_SET(*this, FIX::PriceType);
-    FIELD_SET(*this, FIX::UnderlyingTradingSessionID);
-    FIELD_SET(*this, FIX::QtyType);
-    FIELD_SET(*this, FIX::UnderlyingTradingSessionSubID);
-    FIELD_SET(*this, FIX::LastQty);
-    FIELD_SET(*this, FIX::LastPx);
-    FIELD_SET(*this, FIX::LastParPx);
-    FIELD_SET(*this, FIX::LastSpotRate);
-    FIELD_SET(*this, FIX::LastForwardPoints);
-    FIELD_SET(*this, FIX::LastMkt);
-    FIELD_SET(*this, FIX::TradeDate);
-    FIELD_SET(*this, FIX::ClearingBusinessDate);
-    FIELD_SET(*this, FIX::AvgPx);
-    FIELD_SET(*this, FIX::AvgPxIndicator);
-    FIELD_SET(*this, FIX::MultiLegReportingType);
-    FIELD_SET(*this, FIX::TradeLegRefID);
-    FIELD_SET(*this, FIX::SettlType);
-    FIELD_SET(*this, FIX::MatchStatus);
-    FIELD_SET(*this, FIX::MatchType);
-    FIELD_SET(*this, FIX::CopyMsgIndicator);
-    FIELD_SET(*this, FIX::PublishTrdIndicator);
-    FIELD_SET(*this, FIX::ShortSaleReason);
-    FIELD_SET(*this, FIX::SettlDate);
-    FIELD_SET(*this, FIX::SettlSessID);
-    FIELD_SET(*this, FIX::SettlSessSubID);
     FIELD_SET(*this, FIX::NoPosAmt);
     class NoPosAmt: public FIX::Group
     {
@@ -301,7 +414,7 @@ namespace FIX50SP2
     class NoSides: public FIX::Group
     {
     public:
-    NoSides() : FIX::Group(552,54,FIX::message_order(54,453,1,660,581,81,575,576,578,579,376,377,582,336,625,943,12,13,479,497,157,230,158,159,738,920,921,922,238,237,118,119,155,156,77,752,518,232,136,825,826,591,70,78,1072,1057,1009,1005,1006,1007,83,1008,1016,430,1154,1155,1158,1427,1428,1429,1115,37,198,11,526,66,1080,1081,1431,40,44,99,18,39,151,14,59,126,528,529,1432,821,1093,483,586,775,0)) {}
+    NoSides() : FIX::Group(552,54,FIX::message_order(54,453,1,660,581,81,575,576,578,579,376,377,582,336,625,943,430,1154,1155,12,13,479,497,157,230,158,159,738,920,921,922,238,237,118,119,155,156,77,752,518,232,136,825,1158,826,591,70,78,1072,1057,1009,1005,1006,1007,83,1008,1016,1427,1428,1429,1115,37,198,11,526,66,1080,1081,1431,40,44,99,18,39,151,14,59,126,528,529,1432,821,1093,483,586,775,0)) {}
       FIELD_SET(*this, FIX::Side);
       FIELD_SET(*this, FIX::NoPartyIDs);
       class NoPartyIDs: public FIX::Group
@@ -340,6 +453,9 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::TradingSessionID);
       FIELD_SET(*this, FIX::TradingSessionSubID);
       FIELD_SET(*this, FIX::TimeBracket);
+      FIELD_SET(*this, FIX::NetGrossInd);
+      FIELD_SET(*this, FIX::SideCurrency);
+      FIELD_SET(*this, FIX::SideSettlCurrency);
       FIELD_SET(*this, FIX::Commission);
       FIELD_SET(*this, FIX::CommType);
       FIELD_SET(*this, FIX::CommCurrency);
@@ -388,6 +504,30 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::MiscFeeBasis);
       };
       FIELD_SET(*this, FIX::ExchangeRule);
+      FIELD_SET(*this, FIX::NoSettlDetails);
+      class NoSettlDetails: public FIX::Group
+      {
+      public:
+      NoSettlDetails() : FIX::Group(1158,1164,FIX::message_order(1164,781,0)) {}
+        FIELD_SET(*this, FIX::SettlObligSource);
+        FIELD_SET(*this, FIX::NoSettlPartyIDs);
+        class NoSettlPartyIDs: public FIX::Group
+        {
+        public:
+        NoSettlPartyIDs() : FIX::Group(781,782,FIX::message_order(782,783,784,801,0)) {}
+          FIELD_SET(*this, FIX::SettlPartyID);
+          FIELD_SET(*this, FIX::SettlPartyIDSource);
+          FIELD_SET(*this, FIX::SettlPartyRole);
+          FIELD_SET(*this, FIX::NoSettlPartySubIDs);
+          class NoSettlPartySubIDs: public FIX::Group
+          {
+          public:
+          NoSettlPartySubIDs() : FIX::Group(801,785,FIX::message_order(785,786,0)) {}
+            FIELD_SET(*this, FIX::SettlPartySubID);
+            FIELD_SET(*this, FIX::SettlPartySubIDType);
+          };
+        };
+      };
       FIELD_SET(*this, FIX::TradeAllocIndicator);
       FIELD_SET(*this, FIX::PreallocMethod);
       FIELD_SET(*this, FIX::AllocID);
@@ -440,33 +580,6 @@ namespace FIX50SP2
         FIELD_SET(*this, FIX::SideTrdRegTimestampType);
         FIELD_SET(*this, FIX::SideTrdRegTimestampSrc);
       };
-      FIELD_SET(*this, FIX::NetGrossInd);
-      FIELD_SET(*this, FIX::SideCurrency);
-      FIELD_SET(*this, FIX::SideSettlCurrency);
-      FIELD_SET(*this, FIX::NoSettlDetails);
-      class NoSettlDetails: public FIX::Group
-      {
-      public:
-      NoSettlDetails() : FIX::Group(1158,1164,FIX::message_order(1164,781,0)) {}
-        FIELD_SET(*this, FIX::SettlObligSource);
-        FIELD_SET(*this, FIX::NoSettlPartyIDs);
-        class NoSettlPartyIDs: public FIX::Group
-        {
-        public:
-        NoSettlPartyIDs() : FIX::Group(781,782,FIX::message_order(782,783,784,801,0)) {}
-          FIELD_SET(*this, FIX::SettlPartyID);
-          FIELD_SET(*this, FIX::SettlPartyIDSource);
-          FIELD_SET(*this, FIX::SettlPartyRole);
-          FIELD_SET(*this, FIX::NoSettlPartySubIDs);
-          class NoSettlPartySubIDs: public FIX::Group
-          {
-          public:
-          NoSettlPartySubIDs() : FIX::Group(801,785,FIX::message_order(785,786,0)) {}
-            FIELD_SET(*this, FIX::SettlPartySubID);
-            FIELD_SET(*this, FIX::SettlPartySubIDType);
-          };
-        };
-      };
       FIELD_SET(*this, FIX::SideExecID);
       FIELD_SET(*this, FIX::OrderDelay);
       FIELD_SET(*this, FIX::OrderDelayUnit);
@@ -497,124 +610,10 @@ namespace FIX50SP2
       FIELD_SET(*this, FIX::OrigOrdModTime);
       FIELD_SET(*this, FIX::BookingType);
     };
-    FIELD_SET(*this, FIX::AsOfIndicator);
-    FIELD_SET(*this, FIX::TradeID);
-    FIELD_SET(*this, FIX::SecondaryTradeID);
-    FIELD_SET(*this, FIX::FirmTradeID);
-    FIELD_SET(*this, FIX::SecondaryFirmTradeID);
-    FIELD_SET(*this, FIX::CalculatedCcyLastQty);
-    FIELD_SET(*this, FIX::LastSwapPoints);
-    FIELD_SET(*this, FIX::GrossTradeAmt);
-    FIELD_SET(*this, FIX::NoRootPartyIDs);
-    class NoRootPartyIDs: public FIX::Group
-    {
-    public:
-    NoRootPartyIDs() : FIX::Group(1116,1117,FIX::message_order(1117,1118,1119,1120,0)) {}
-      FIELD_SET(*this, FIX::RootPartyID);
-      FIELD_SET(*this, FIX::RootPartyIDSource);
-      FIELD_SET(*this, FIX::RootPartyRole);
-      FIELD_SET(*this, FIX::NoRootPartySubIDs);
-      class NoRootPartySubIDs: public FIX::Group
-      {
-      public:
-      NoRootPartySubIDs() : FIX::Group(1120,1121,FIX::message_order(1121,1122,0)) {}
-        FIELD_SET(*this, FIX::RootPartySubID);
-        FIELD_SET(*this, FIX::RootPartySubIDType);
-      };
-    };
-    FIELD_SET(*this, FIX::TradeHandlingInstr);
-    FIELD_SET(*this, FIX::OrigTradeHandlingInstr);
-    FIELD_SET(*this, FIX::OrigTradeDate);
-    FIELD_SET(*this, FIX::OrigTradeID);
-    FIELD_SET(*this, FIX::OrigSecondaryTradeID);
-    FIELD_SET(*this, FIX::NoUnderlyings);
-    class NoUnderlyings: public FIX::Group
-    {
-    public:
-    NoUnderlyings() : FIX::Group(711,311,FIX::message_order(311,312,309,305,462,463,310,763,313,542,241,242,243,244,245,246,256,595,592,593,594,247,316,941,317,436,435,308,306,362,363,307,364,365,877,878,318,879,810,882,883,884,885,886,972,975,973,974,998,1000,1038,1039,1044,1045,1046,1213,315,1419,1423,1424,1425,1437,1441,1453,1454,1455,1456,1459,1460,0)) {}
-      FIELD_SET(*this, FIX::UnderlyingSymbol);
-      FIELD_SET(*this, FIX::UnderlyingSymbolSfx);
-      FIELD_SET(*this, FIX::UnderlyingSecurityID);
-      FIELD_SET(*this, FIX::UnderlyingSecurityIDSource);
-      FIELD_SET(*this, FIX::UnderlyingProduct);
-      FIELD_SET(*this, FIX::UnderlyingCFICode);
-      FIELD_SET(*this, FIX::UnderlyingSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingSecuritySubType);
-      FIELD_SET(*this, FIX::UnderlyingMaturityMonthYear);
-      FIELD_SET(*this, FIX::UnderlyingMaturityDate);
-      FIELD_SET(*this, FIX::UnderlyingCouponPaymentDate);
-      FIELD_SET(*this, FIX::UnderlyingIssueDate);
-      FIELD_SET(*this, FIX::UnderlyingRepoCollateralSecurityType);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseTerm);
-      FIELD_SET(*this, FIX::UnderlyingRepurchaseRate);
-      FIELD_SET(*this, FIX::UnderlyingFactor);
-      FIELD_SET(*this, FIX::UnderlyingCreditRating);
-      FIELD_SET(*this, FIX::UnderlyingInstrRegistry);
-      FIELD_SET(*this, FIX::UnderlyingCountryOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingStateOrProvinceOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingLocaleOfIssue);
-      FIELD_SET(*this, FIX::UnderlyingRedemptionDate);
-      FIELD_SET(*this, FIX::UnderlyingStrikePrice);
-      FIELD_SET(*this, FIX::UnderlyingStrikeCurrency);
-      FIELD_SET(*this, FIX::UnderlyingOptAttribute);
-      FIELD_SET(*this, FIX::UnderlyingContractMultiplier);
-      FIELD_SET(*this, FIX::UnderlyingCouponRate);
-      FIELD_SET(*this, FIX::UnderlyingSecurityExchange);
-      FIELD_SET(*this, FIX::UnderlyingIssuer);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuerLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingIssuer);
-      FIELD_SET(*this, FIX::UnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDescLen);
-      FIELD_SET(*this, FIX::EncodedUnderlyingSecurityDesc);
-      FIELD_SET(*this, FIX::UnderlyingCPProgram);
-      FIELD_SET(*this, FIX::UnderlyingCPRegType);
-      FIELD_SET(*this, FIX::UnderlyingCurrency);
-      FIELD_SET(*this, FIX::UnderlyingQty);
-      FIELD_SET(*this, FIX::UnderlyingPx);
-      FIELD_SET(*this, FIX::UnderlyingDirtyPrice);
-      FIELD_SET(*this, FIX::UnderlyingEndPrice);
-      FIELD_SET(*this, FIX::UnderlyingStartValue);
-      FIELD_SET(*this, FIX::UnderlyingCurrentValue);
-      FIELD_SET(*this, FIX::UnderlyingEndValue);
-      FIELD_SET(*this, FIX::UnderlyingAllocationPercent);
-      FIELD_SET(*this, FIX::UnderlyingSettlementType);
-      FIELD_SET(*this, FIX::UnderlyingCashAmount);
-      FIELD_SET(*this, FIX::UnderlyingCashType);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingTimeUnit);
-      FIELD_SET(*this, FIX::UnderlyingCapValue);
-      FIELD_SET(*this, FIX::UnderlyingSettlMethod);
-      FIELD_SET(*this, FIX::UnderlyingAdjustedQuantity);
-      FIELD_SET(*this, FIX::UnderlyingFXRate);
-      FIELD_SET(*this, FIX::UnderlyingFXRateCalc);
-      FIELD_SET(*this, FIX::UnderlyingMaturityTime);
-      FIELD_SET(*this, FIX::UnderlyingPutOrCall);
-      FIELD_SET(*this, FIX::UnderlyingExerciseStyle);
-      FIELD_SET(*this, FIX::UnderlyingUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasure);
-      FIELD_SET(*this, FIX::UnderlyingPriceUnitOfMeasureQty);
-      FIELD_SET(*this, FIX::UnderlyingContractMultiplierUnit);
-      FIELD_SET(*this, FIX::UnderlyingFlowScheduleType);
-      FIELD_SET(*this, FIX::UnderlyingRestructuringType);
-      FIELD_SET(*this, FIX::UnderlyingSeniority);
-      FIELD_SET(*this, FIX::UnderlyingNotionalPercentageOutstanding);
-      FIELD_SET(*this, FIX::UnderlyingOriginalNotionalPercentageOutstanding);
-      FIELD_SET(*this, FIX::UnderlyingAttachmentPoint);
-      FIELD_SET(*this, FIX::UnderlyingDetachmentPoint);
-    };
     FIELD_SET(*this, FIX::RptSys);
-    FIELD_SET(*this, FIX::Currency);
-    FIELD_SET(*this, FIX::SettlCurrency);
+    FIELD_SET(*this, FIX::GrossTradeAmt);
+    FIELD_SET(*this, FIX::SettlDate);
     FIELD_SET(*this, FIX::FeeMultiplier);
-    FIELD_SET(*this, FIX::NoTrdRepIndicators);
-    class NoTrdRepIndicators: public FIX::Group
-    {
-    public:
-    NoTrdRepIndicators() : FIX::Group(1387,1388,FIX::message_order(1388,1389,0)) {}
-      FIELD_SET(*this, FIX::TrdRepPartyRole);
-      FIELD_SET(*this, FIX::TrdRepIndicator);
-    };
-    FIELD_SET(*this, FIX::TradePublishIndicator);
     FIELD_SET(*this, FIX::VenueType);
     FIELD_SET(*this, FIX::MarketSegmentID);
     FIELD_SET(*this, FIX::MarketID);
