@@ -1,5 +1,5 @@
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -112,6 +112,19 @@ TEST(isEmpty)
   CHECK( message.isEmpty() );
 }
 
+TEST(getFieldIfPresent)
+{
+  FIX::Message message;
+  FIX::MsgType initial("A");
+  CHECK( !message.getFieldIfSet( initial ) );
+  CHECK( initial == FIX::MsgType("A") );
+
+  message.setField( initial );
+  FIX::MsgType stored;
+  CHECK( message.getFieldIfSet( stored ) );
+  CHECK( stored == initial );
+}
+
 TEST(setString)
 {
   static const char* strGood =
@@ -197,6 +210,21 @@ TEST(setStringWithGroup)
   CHECK_EQUAL( str, object.toString() );
 }
 
+TEST(setStringWithGroupWithoutDelimiter)
+{
+  FIX::Message object;
+  DataDictionary dataDictionary( "../spec/FIX43.xml" );
+  static const char* str =
+    "8=FIX.4.3\0019=171\00135=E\00134=126\00149=BUYSIDE\00150=00303\00152"
+    "=20040916-16:19:18.328\00156=SELLSIDE\00166=1095350459\00168=2\00173=2\001"
+    "67=1\0011=00303\00155=fred\00154=1\00140=1\00159=3\001"
+    "67=2\0011=00303\00155=fred\00154=1\00140=1\00159=3\001394=3\00110="
+    "054\001";
+
+  object.setString( str, true, &dataDictionary );
+  CHECK_EQUAL( str, object.toString() );
+}
+
 TEST(setStringWithHeaderGroup)
 {
   FIX::Message object;
@@ -352,27 +380,27 @@ TEST(getXML)
           << "  <header>" << std::endl
           << "    <field name=\"BeginString\" number=\"8\"><![CDATA[FIX.4.2]]></field>" << std::endl
           << "    <field name=\"MsgType\" number=\"35\" enum=\"Logon\"><![CDATA[A]]></field>" << std::endl
-	  << "    <field name=\"SenderCompID\" number=\"49\"><![CDATA[SENDER]]></field>" << std::endl
-	  << "    <field name=\"TargetCompID\" number=\"56\"><![CDATA[TARGET]]></field>" << std::endl
-	  << "  </header>" << std::endl
+          << "    <field name=\"SenderCompID\" number=\"49\"><![CDATA[SENDER]]></field>" << std::endl
+          << "    <field name=\"TargetCompID\" number=\"56\"><![CDATA[TARGET]]></field>" << std::endl
+          << "  </header>" << std::endl
           << "  <body>" << std::endl
-	  << "    <field name=\"Account\" number=\"1\"><![CDATA[ACCOUNT]]></field>" << std::endl
-	  << "    <field name=\"ClOrdID\" number=\"11\"><![CDATA[CLORDID]]></field>" << std::endl
-	  << "    <field name=\"IDSource\" number=\"22\" enum=\"CUSIP\"><![CDATA[1]]></field>" << std::endl
-	  << "    <field name=\"NoMsgTypes\" number=\"384\"><![CDATA[2]]></field>" << std::endl
-	  << "    <group>" << std::endl
-	  << "      <field name=\"RefMsgType\" number=\"372\"><![CDATA[A]]></field>" << std::endl
-	  << "      <field name=\"MsgDirection\" number=\"385\"><![CDATA[0]]></field>" << std::endl
-	  << "    </group>" << std::endl
-	  << "    <group>" << std::endl
-	  << "      <field name=\"RefMsgType\" number=\"372\"><![CDATA[0]]></field>" << std::endl
-	  << "      <field name=\"MsgDirection\" number=\"385\"><![CDATA[1]]></field>" << std::endl
-	  << "    </group>" << std::endl
-	  << "  </body>" << std::endl
-	  << "  <trailer>" << std::endl
-	  << "    <field name=\"CheckSum\" number=\"10\"><![CDATA[132]]></field>" << std::endl
-	  << "  </trailer>" << std::endl
-	  << "</message>";
+          << "    <field name=\"Account\" number=\"1\"><![CDATA[ACCOUNT]]></field>" << std::endl
+          << "    <field name=\"ClOrdID\" number=\"11\"><![CDATA[CLORDID]]></field>" << std::endl
+          << "    <field name=\"IDSource\" number=\"22\" enum=\"CUSIP\"><![CDATA[1]]></field>" << std::endl
+          << "    <field name=\"NoMsgTypes\" number=\"384\"><![CDATA[2]]></field>" << std::endl
+          << "    <group>" << std::endl
+          << "      <field name=\"RefMsgType\" number=\"372\"><![CDATA[A]]></field>" << std::endl
+          << "      <field name=\"MsgDirection\" number=\"385\"><![CDATA[0]]></field>" << std::endl
+          << "    </group>" << std::endl
+          << "    <group>" << std::endl
+          << "      <field name=\"RefMsgType\" number=\"372\"><![CDATA[0]]></field>" << std::endl
+          << "      <field name=\"MsgDirection\" number=\"385\"><![CDATA[1]]></field>" << std::endl
+          << "    </group>" << std::endl
+          << "  </body>" << std::endl
+          << "  <trailer>" << std::endl
+          << "    <field name=\"CheckSum\" number=\"10\"><![CDATA[132]]></field>" << std::endl
+          << "  </trailer>" << std::endl
+          << "</message>";
 
   CHECK_EQUAL( stream.str(), message.toXML() );
 }
@@ -473,7 +501,7 @@ TEST(addRemoveGroup)
   CHECK( object.hasGroup(1, group) );
   CHECK( object.hasGroup(2, group) );
   CHECK( object.hasGroup(3, group) );
-  CHECK_EQUAL( 3, object.groupCount(FIX::FIELD::NoOrders) );
+  CHECK_EQUAL( 3lu, object.groupCount(FIX::FIELD::NoOrders) );
   object.getField( noOrders );
   CHECK_EQUAL( 3, noOrders );
 
@@ -481,7 +509,7 @@ TEST(addRemoveGroup)
   CHECK( object.hasGroup(1, group) );
   CHECK( object.hasGroup(2, group) );
   CHECK( !object.hasGroup(3, group) );
-  CHECK_EQUAL( 2, object.groupCount(FIX::FIELD::NoOrders) );
+  CHECK_EQUAL( 2lu, object.groupCount(FIX::FIELD::NoOrders) );
   object.getField( noOrders );
   CHECK_EQUAL( 2, noOrders );
 
@@ -489,7 +517,7 @@ TEST(addRemoveGroup)
   CHECK( object.hasGroup(1, group) );
   CHECK( !object.hasGroup(2, group) );
   CHECK( !object.hasGroup(3, group) );
-  CHECK_EQUAL( 1, object.groupCount(FIX::FIELD::NoOrders) );
+  CHECK_EQUAL( 1lu, object.groupCount(FIX::FIELD::NoOrders) );
   object.getField( noOrders );
   CHECK_EQUAL( 1, noOrders );
 
@@ -497,8 +525,8 @@ TEST(addRemoveGroup)
   CHECK( !object.hasGroup(1, group) );
   CHECK( !object.hasGroup(2, group) );
   CHECK( !object.hasGroup(3, group) );
-  CHECK_EQUAL( 0, object.groupCount(FIX::FIELD::NoOrders) );
-  !object.isSetField( noOrders );
+  CHECK_EQUAL( 0lu, object.groupCount(FIX::FIELD::NoOrders) );
+  CHECK( !object.isSetField( noOrders ) );
 }
 
 TEST(replaceGroup)
@@ -538,7 +566,7 @@ TEST(replaceGroup)
   CHECK( object.hasGroup(1, group) );
   CHECK( object.hasGroup(2, group) );
   CHECK( object.hasGroup(3, group) );
-  CHECK_EQUAL( 3, object.groupCount(FIX::FIELD::NoOrders) );
+  CHECK_EQUAL( 3lu, object.groupCount(FIX::FIELD::NoOrders) );
   object.getField( noOrders );
   CHECK_EQUAL( 3, noOrders );
 
@@ -582,7 +610,7 @@ TEST(testRequestGetString)
   object.set( TestReqID( "23" ) );
 
   CHECK_EQUAL( "8=FIX.4.2\0019=12\00135=1\001112=23\00110=007\001",
-	       object.toString() );
+               object.toString() );
 }
 
 TEST(testRequestSetString)
