@@ -1,5 +1,5 @@
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -352,7 +352,7 @@ struct sessionFixture : public TestCallback
     TimeRange sessionTime( startTime, endTime );
 
     DataDictionaryProvider provider;
-    provider.addTransportDataDictionary( sessionID.getBeginString(), DataDictionary("../spec/FIX42.xml") );
+    provider.addTransportDataDictionary( sessionID.getBeginString(), "../spec/FIX42.xml" );
     object = new Session( *this, factory, sessionID, provider,
                            sessionTime, heartBtInt, 0 );
     object->setResponder( this );
@@ -391,9 +391,9 @@ struct sessionT11Fixture : public TestCallback
     TimeRange sessionTime( startTime, endTime );
 
     DataDictionaryProvider provider;
-    provider.addTransportDataDictionary( sessionID.getBeginString(), DataDictionary("../spec/FIXT11.xml") );
-    provider.addApplicationDataDictionary( ApplVerID(ApplVerID_FIX50), DataDictionary("../spec/FIX50.xml") );
-    provider.addApplicationDataDictionary( ApplVerID(ApplVerID_FIX42), DataDictionary("../spec/FIX42.xml") );
+    provider.addTransportDataDictionary( sessionID.getBeginString(), "../spec/FIXT11.xml" );
+    provider.addApplicationDataDictionary( ApplVerID(ApplVerID_FIX50), "../spec/FIX50.xml" );
+    provider.addApplicationDataDictionary( ApplVerID(ApplVerID_FIX42), "../spec/FIX42.xml" );
     object = new Session( *this, factory, sessionID, provider,
                            sessionTime, heartBtInt, 0 );
     object->setSenderDefaultApplVerID( FIX::Message::toApplVerID(BeginString("FIX.5.0")) );
@@ -615,7 +615,7 @@ TEST_FIXTURE(acceptorFixture, callDisconnect)
 TEST_FIXTURE(sessionFixture, doesSessionExist)
 {
   DataDictionaryProvider provider;
-  provider.addTransportDataDictionary( BeginString("FIX.4.2"), DataDictionary() );
+  provider.addTransportDataDictionary( BeginString("FIX.4.2"), std::shared_ptr<DataDictionary>(new DataDictionary()) );
 
   Session * pSession1 = new Session
     ( *this, factory, SessionID( BeginString( "FIX.4.2" ),
@@ -657,25 +657,25 @@ TEST_FIXTURE(sessionFixture, doesSessionExist)
           ( SessionID( BeginString( "FIX.4.2" ), SenderCompID( "OREN" ),
                        TargetCompID( "NERO" ) ) ) );
 
-  CHECK_EQUAL( 4, Session::numSessions() );
+  CHECK_EQUAL( 4lu, Session::numSessions() );
 
   delete pSession1;
 
   CHECK( !Session::doesSessionExist
           ( SessionID( BeginString( "FIX.4.2" ),
                        SenderCompID( "TW" ), TargetCompID( "ISLD" ) ) ) );
-  CHECK_EQUAL( 3, Session::numSessions() );
+  CHECK_EQUAL( 3lu, Session::numSessions() );
 
   delete pSession2;
   delete pSession3;
 
-  CHECK_EQUAL( 1, Session::numSessions() );
+  CHECK_EQUAL( 1lu, Session::numSessions() );
   CHECK( Session::doesSessionExist
           ( SessionID( BeginString( "FIX.4.2" ), SenderCompID( "OREN" ),
                        TargetCompID( "NERO" ) ) ) );
 
   delete pSession4;
-  CHECK_EQUAL( 0, Session::numSessions() );
+  CHECK_EQUAL( 0lu, Session::numSessions() );
   CHECK( !Session::doesSessionExist
           ( SessionID( BeginString( "FIX.4.2" ), SenderCompID( "OREN" ),
                        TargetCompID( "NERO" ) ) ) );
@@ -686,7 +686,7 @@ TEST_FIXTURE(sessionFixture, doesSessionExist)
 TEST_FIXTURE(sessionFixture, lookupSession)
 {
   DataDictionaryProvider provider;
-  provider.addTransportDataDictionary( BeginString("FIX.4.2"), DataDictionary() );
+  provider.addTransportDataDictionary( BeginString("FIX.4.2"), std::shared_ptr<DataDictionary>(new DataDictionary()) );
 
   Session* pSession1 = new Session
     ( *this, factory, SessionID( BeginString( "FIX.4.2" ),
@@ -741,7 +741,7 @@ TEST_FIXTURE(sessionFixture, lookupSession)
 TEST_FIXTURE(sessionFixture, registerSession)
 {
   DataDictionaryProvider provider;
-  provider.addTransportDataDictionary( BeginString("FIX.4.2"), DataDictionary() );
+  provider.addTransportDataDictionary( BeginString("FIX.4.2"), std::shared_ptr<DataDictionary>(new DataDictionary()) );
 
   Session* pSession = new Session
     ( *this, factory, SessionID( BeginString( "FIX.4.2" ),
@@ -1173,8 +1173,20 @@ TEST_FIXTURE(acceptorFixture, unsupportedMsgType)
   CHECK_EQUAL( 1, toBusinessMessageReject );
 }
 
+TEST_FIXTURE(acceptorFixture, doNotRespondToLogonWhenDisabled)
+{
+  object->setResponder( this );
+  object->logout();
+  object->next( createLogon( "ISLD", "TW", 1 ), UtcTimeStamp() );
+
+  CHECK_EQUAL( 0, toLogon );
+  CHECK_EQUAL( 0, toLogout );
+}
+
 struct resetOnEndTimeFixture : public acceptorFixture
 {
+  using acceptorFixture::createSession;
+
   void createSession()
   {
     startTimeStamp.setCurrent();
@@ -1192,9 +1204,8 @@ struct resetOnEndTimeFixture : public acceptorFixture
 
 TEST_FIXTURE(resetOnEndTimeFixture, resetOnEndTime)
 {
-  UtcTimeStamp timeStamp = startTimeStamp;
-
   createSession();
+  UtcTimeStamp timeStamp = startTimeStamp;
   object->next( createLogon( "ISLD", "TW", 1 ), timeStamp );
   object->next( createHeartbeat( "ISLD", "TW", 2 ), timeStamp );
 
@@ -1203,7 +1214,7 @@ TEST_FIXTURE(resetOnEndTimeFixture, resetOnEndTime)
   timeStamp += 1;
   object->next( timeStamp );
   CHECK_EQUAL( 0, disconnected );
-  timeStamp += 1;
+  timeStamp += 2;
   object->next( timeStamp );
   CHECK_EQUAL( 1, disconnected );
   CHECK_EQUAL( 1, toLogout );
@@ -1319,4 +1330,70 @@ TEST_FIXTURE(acceptorFixture, processQueuedMessages)
   CHECK_EQUAL( 2, toResendRequest );
 }
 
+struct initiatorCreatedBeforeStartTimeFixture : public TestCallback
+{
+  static const int HEARTBTINT = 30;
+  static const int STARTTIMEFROMNOW = 2;
+  static const int ENDTIMEFROMNOW = 4;
+
+  int actuallySent;
+  bool actuallySentLogon;
+  Session * object;
+  MemoryStoreFactory memStoreFactory;
+
+  initiatorCreatedBeforeStartTimeFixture()
+    : actuallySent(0), actuallySentLogon(false)
+  {
+    startTime.setCurrent();
+    startTime.setMillisecond(0);
+    startTime += STARTTIMEFROMNOW;
+    endTime.setCurrent();
+    endTime.setMillisecond(0);
+    endTime += ENDTIMEFROMNOW;
+    TimeRange sessionTime( startTime, endTime );
+
+    SessionID sessionID( BeginString( "FIX.4.2" ), SenderCompID( "MJKG" ), TargetCompID( "IZZY" ) );
+    
+    DataDictionaryProvider provider;
+    provider.addTransportDataDictionary( sessionID.getBeginString(), "../spec/FIX42.xml" );
+    object = new Session( *this, memStoreFactory, sessionID, provider, sessionTime, HEARTBTINT, 0 );
+  }
+
+  virtual ~initiatorCreatedBeforeStartTimeFixture()
+  {
+    if(object)
+      delete object;
+  }
+
+  bool send( const std::string& s)
+  {
+    std::string::size_type p = s.find( "\00135=A\001", 0 );
+    if( p != std::string::npos )
+      actuallySentLogon = true;
+    
+    actuallySent++;
+    return true;
+  }
+};
+
+/** 
+  * Verifies bug fix: only a Logon should be sent at
+  * StartTime, not Logout followed by Logon
+  */
+TEST_FIXTURE(initiatorCreatedBeforeStartTimeFixture, initiatorLogonAtStartTime)
+{
+  process_sleep( STARTTIMEFROMNOW );
+  
+  CHECK_EQUAL( 0, toLogon );
+  CHECK_EQUAL( 0, actuallySent);
+  CHECK_EQUAL( false, actuallySentLogon);
+  
+  object->setResponder( this );
+  object->next();
+  
+  CHECK_EQUAL( 1, toLogon );
+  CHECK_EQUAL( 1, actuallySent);
+  CHECK_EQUAL( true, actuallySentLogon);
+}
+
 }
