@@ -1,7 +1,7 @@
 /* -*- C++ -*- */
 
 /****************************************************************************
-** Copyright (c) quickfixengine.org  All rights reserved.
+** Copyright (c) 2001-2014
 **
 ** This file is part of the QuickFIX FIX Engine
 **
@@ -26,6 +26,7 @@
 #include "config.h"
 #endif
 
+#include <memory>
 #include "getopt-repl.h"
 #include <iostream>
 #include "Application.h"
@@ -45,29 +46,32 @@
 #include "fix42/NewOrderSingle.h"
 #include "fix42/QuoteRequest.h"
 
-int testIntegerToString( int );
-int testStringToInteger( int );
-int testDoubleToString( int );
-int testStringToDouble( int );
-int testCreateHeartbeat( int );
-int testIdentifyType( int );
-int testSerializeToStringHeartbeat( int );
-int testSerializeFromStringHeartbeat( int );
-int testCreateNewOrderSingle( int );
-int testSerializeToStringNewOrderSingle( int );
-int testSerializeFromStringNewOrderSingle( int );
-int testCreateQuoteRequest( int );
-int testReadFromQuoteRequest( int );
-int testSerializeToStringQuoteRequest( int );
-int testSerializeFromStringQuoteRequest( int );
-int testFileStoreNewOrderSingle( int );
-int testValidateNewOrderSingle( int );
-int testValidateDictNewOrderSingle( int );
-int testValidateQuoteRequest( int );
-int testValidateDictQuoteRequest( int );
-int testSendOnSocket( int, short );
-int testSendOnThreadedSocket( int, short );
-void report( int, int );
+long testIntegerToString( int );
+long testStringToInteger( int );
+long testDoubleToString( int );
+long testStringToDouble( int );
+long testCreateHeartbeat( int );
+long testIdentifyType( int );
+long testSerializeToStringHeartbeat( int );
+long testSerializeFromStringHeartbeat( int );
+long testSerializeFromStringAndValidateHeartbeat( int );
+long testCreateNewOrderSingle( int );
+long testSerializeToStringNewOrderSingle( int );
+long testSerializeFromStringNewOrderSingle( int );
+long testSerializeFromStringAndValidateNewOrderSingle( int );
+long testCreateQuoteRequest( int );
+long testReadFromQuoteRequest( int );
+long testSerializeToStringQuoteRequest( int );
+long testSerializeFromStringQuoteRequest( int );
+long testSerializeFromStringAndValidateQuoteRequest( int );
+long testFileStoreNewOrderSingle( int );
+long testValidateNewOrderSingle( int );
+long testValidateDictNewOrderSingle( int );
+long testValidateQuoteRequest( int );
+long testValidateDictQuoteRequest( int );
+long testSendOnSocket( int, short );
+long testSendOnThreadedSocket( int, short );
+void report( long, int );
 
 #ifndef _MSC_VER
 #include <sys/time.h>
@@ -82,6 +86,10 @@ long GetTickCount()
 }
 #endif
 
+std::auto_ptr<FIX::DataDictionary> s_dataDictionary;
+const bool VALIDATE = true;
+const bool DONT_VALIDATE = false;
+
 int main( int argc, char** argv )
 {
   int count = 0;
@@ -96,7 +104,7 @@ int main( int argc, char** argv )
       port = (short)atol( optarg );
       break;
     case 'c':
-      count = atol( optarg );
+      count = atoi( optarg );
       break;
     default:
       std::cout << "usage: "
@@ -106,6 +114,8 @@ int main( int argc, char** argv )
     }
   }
 
+  s_dataDictionary.reset( new FIX::DataDictionary( "../spec/FIX42.xml" ) );
+
   std::cout << "Converting integers to strings: ";
   report( testIntegerToString( count ), count );
 
@@ -130,6 +140,9 @@ int main( int argc, char** argv )
   std::cout << "Serializing Heartbeat messages from strings: ";
   report( testSerializeFromStringHeartbeat( count ), count );
 
+  std::cout << "Serializing Heartbeat messages from strings and validation: ";
+  report( testSerializeFromStringAndValidateHeartbeat( count ), count );
+
   std::cout << "Creating NewOrderSingle messages: ";
   report( testCreateNewOrderSingle( count ), count );
 
@@ -139,6 +152,9 @@ int main( int argc, char** argv )
   std::cout << "Serializing NewOrderSingle messages from strings: ";
   report( testSerializeFromStringNewOrderSingle( count ), count );
 
+  std::cout << "Serializing NewOrderSingle messages from strings and validation: ";
+  report( testSerializeFromStringAndValidateNewOrderSingle( count ), count );
+
   std::cout << "Creating QuoteRequest messages: ";
   report( testCreateQuoteRequest( count ), count );
 
@@ -148,6 +164,9 @@ int main( int argc, char** argv )
   std::cout << "Serializing QuoteRequest messages from strings: ";
   report( testSerializeFromStringQuoteRequest( count ), count );
 
+  std::cout << "Serializing QuoteRequest messages from strings and validation: ";
+  report( testSerializeFromStringAndValidateQuoteRequest( count ), count );
+
   std::cout << "Reading fields from QuoteRequest message: ";
   report( testReadFromQuoteRequest( count ), count );
 
@@ -175,7 +194,7 @@ int main( int argc, char** argv )
   return 0;
 }
 
-void report( int time, int count )
+void report( long time, int count )
 {
   double seconds = ( double ) time / 1000;
   double num_per_second = count / seconds;
@@ -184,11 +203,11 @@ void report( int time, int count )
   << ", num_per_second: " << num_per_second << std::endl;
 }
 
-int testIntegerToString( int count )
+long testIntegerToString( int count )
 {
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::IntConvertor::convert( 1234 );
@@ -196,12 +215,12 @@ int testIntegerToString( int count )
   return GetTickCount() - start;
 }
 
-int testStringToInteger( int count )
+long testStringToInteger( int count )
 {
   std::string value( "1234" );
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::IntConvertor::convert( value );
@@ -209,11 +228,11 @@ int testStringToInteger( int count )
   return GetTickCount() - start;
 }
 
-int testDoubleToString( int count )
+long testDoubleToString( int count )
 {
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::DoubleConvertor::convert( 123.45 );
@@ -221,12 +240,12 @@ int testDoubleToString( int count )
   return GetTickCount() - start;
 }
 
-int testStringToDouble( int count )
+long testStringToDouble( int count )
 {
   std::string value( "123.45" );
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::DoubleConvertor::convert( value );
@@ -234,11 +253,11 @@ int testStringToDouble( int count )
   return GetTickCount() - start;
 }
 
-int testCreateHeartbeat( int count )
+long testCreateHeartbeat( int count )
 {
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX42::Heartbeat();
@@ -247,14 +266,14 @@ int testCreateHeartbeat( int count )
   return GetTickCount() - start;
 }
 
-int testIdentifyType( int count )
+long testIdentifyType( int count )
 {
   FIX42::Heartbeat message;
   std::string messageString = message.toString();
 
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::identifyType( messageString );
@@ -263,12 +282,12 @@ int testIdentifyType( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeToStringHeartbeat( int count )
+long testSerializeToStringHeartbeat( int count )
 {
   FIX42::Heartbeat message;
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     message.toString();
@@ -276,23 +295,37 @@ int testSerializeToStringHeartbeat( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeFromStringHeartbeat( int count )
+long testSerializeFromStringHeartbeat( int count )
 {
   FIX42::Heartbeat message;
   std::string string = message.toString();
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
-    message.setString( string );
+    message.setString( string, DONT_VALIDATE, s_dataDictionary.get() );
   }
   return GetTickCount() - start;
 }
 
-int testCreateNewOrderSingle( int count )
+long testSerializeFromStringAndValidateHeartbeat( int count )
 {
-  int start = GetTickCount();
+  FIX42::Heartbeat message;
+  std::string string = message.toString();
+  count = count - 1;
+
+  long start = GetTickCount();
+  for ( int i = 0; i <= count; ++i )
+  {
+    message.setString( string, VALIDATE, s_dataDictionary.get() );
+  }
+  return GetTickCount() - start;
+}
+
+long testCreateNewOrderSingle( int count )
+{
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     FIX::ClOrdID clOrdID( "ORDERID" );
@@ -307,7 +340,7 @@ int testCreateNewOrderSingle( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeToStringNewOrderSingle( int count )
+long testSerializeToStringNewOrderSingle( int count )
 {
   FIX::ClOrdID clOrdID( "ORDERID" );
   FIX::HandlInst handlInst( '1' );
@@ -320,7 +353,7 @@ int testSerializeToStringNewOrderSingle( int count )
 
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     message.toString();
@@ -328,7 +361,7 @@ int testSerializeToStringNewOrderSingle( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeFromStringNewOrderSingle( int count )
+long testSerializeFromStringNewOrderSingle( int count )
 {
   FIX::ClOrdID clOrdID( "ORDERID" );
   FIX::HandlInst handlInst( '1' );
@@ -342,19 +375,41 @@ int testSerializeFromStringNewOrderSingle( int count )
 
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
-    message.setString( string );
+    message.setString( string, DONT_VALIDATE, s_dataDictionary.get() );
   }
   return GetTickCount() - start;
 }
 
-int testCreateQuoteRequest( int count )
+long testSerializeFromStringAndValidateNewOrderSingle( int count )
+{
+  FIX::ClOrdID clOrdID( "ORDERID" );
+  FIX::HandlInst handlInst( '1' );
+  FIX::Symbol symbol( "LNUX" );
+  FIX::Side side( FIX::Side_BUY );
+  FIX::TransactTime transactTime;
+  FIX::OrdType ordType( FIX::OrdType_MARKET );
+  FIX42::NewOrderSingle message
+    ( clOrdID, handlInst, symbol, side, transactTime, ordType );
+  std::string string = message.toString();
+
+  count = count - 1;
+
+  long start = GetTickCount();
+  for ( int i = 0; i <= count; ++i )
+  {
+    message.setString( string, VALIDATE, s_dataDictionary.get() );
+  }
+  return GetTickCount() - start;
+}
+
+long testCreateQuoteRequest( int count )
 {
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   FIX::Symbol symbol;
   FIX::MaturityMonthYear maturityMonthYear;
   FIX::PutOrCall putOrCall;
@@ -395,7 +450,7 @@ int testCreateQuoteRequest( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeToStringQuoteRequest( int count )
+long testSerializeToStringQuoteRequest( int count )
 {
   FIX42::QuoteRequest message( FIX::QuoteReqID("1") );
   FIX42::QuoteRequest::NoRelatedSym noRelatedSym;
@@ -415,7 +470,7 @@ int testSerializeToStringQuoteRequest( int count )
 
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int j = 0; j <= count; ++j )
   {
     message.toString();
@@ -423,7 +478,7 @@ int testSerializeToStringQuoteRequest( int count )
   return GetTickCount() - start;
 }
 
-int testSerializeFromStringQuoteRequest( int count )
+long testSerializeFromStringQuoteRequest( int count )
 {
   FIX42::QuoteRequest message( FIX::QuoteReqID("1") );
   FIX42::QuoteRequest::NoRelatedSym noRelatedSym;
@@ -444,15 +499,44 @@ int testSerializeFromStringQuoteRequest( int count )
 
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int j = 0; j <= count; ++j )
   {
-    message.setString( string );
+    message.setString( string, DONT_VALIDATE, s_dataDictionary.get() );
   }
   return GetTickCount() - start;
 }
 
-int testReadFromQuoteRequest( int count )
+long testSerializeFromStringAndValidateQuoteRequest( int count )
+{
+  FIX42::QuoteRequest message( FIX::QuoteReqID("1") );
+  FIX42::QuoteRequest::NoRelatedSym noRelatedSym;
+
+  for( int i = 1; i <= 10; ++i )
+  {
+    noRelatedSym.set( FIX::Symbol("IBM") );
+    noRelatedSym.set( FIX::MaturityMonthYear() );
+    noRelatedSym.set( FIX::PutOrCall(FIX::PutOrCall_PUT) );
+    noRelatedSym.set( FIX::StrikePrice(120) );
+    noRelatedSym.set( FIX::Side(FIX::Side_BUY) );
+    noRelatedSym.set( FIX::OrderQty(100) );
+    noRelatedSym.set( FIX::Currency("USD") );
+    noRelatedSym.set( FIX::OrdType(FIX::OrdType_MARKET) );
+    message.addGroup( noRelatedSym );
+  }
+  std::string string = message.toString();
+
+  count = count - 1;
+
+  long start = GetTickCount();
+  for ( int j = 0; j <= count; ++j )
+  {
+    message.setString( string, VALIDATE, s_dataDictionary.get() );
+  }
+  return GetTickCount() - start;
+}
+
+long testReadFromQuoteRequest( int count )
 {
   count = count - 1;
 
@@ -473,7 +557,7 @@ int testReadFromQuoteRequest( int count )
   }
   group.clear();
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int j = 0; j <= count; ++j )
   {
     FIX::QuoteReqID quoteReqID;
@@ -513,7 +597,7 @@ int testReadFromQuoteRequest( int count )
   return GetTickCount() - start;
 }
 
-int testFileStoreNewOrderSingle( int count )
+long testFileStoreNewOrderSingle( int count )
 {
   FIX::BeginString beginString( FIX::BeginString_FIX42 );
   FIX::SenderCompID senderCompID( "SENDER" );
@@ -535,17 +619,17 @@ int testFileStoreNewOrderSingle( int count )
   store.reset();
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     store.set( ++i, messageString );
   }
-  int end = GetTickCount();
+  long end = GetTickCount();
   store.reset();
   return end - start;
 }
 
-int testValidateNewOrderSingle( int count )
+long testValidateNewOrderSingle( int count )
 {
   FIX::ClOrdID clOrdID( "ORDERID" );
   FIX::HandlInst handlInst( '1' );
@@ -562,7 +646,7 @@ int testValidateNewOrderSingle( int count )
   FIX::DataDictionary dataDictionary;
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
     dataDictionary.validate( message );
@@ -570,7 +654,7 @@ int testValidateNewOrderSingle( int count )
   return GetTickCount() - start;
 }
 
-int testValidateDictNewOrderSingle( int count )
+long testValidateDictNewOrderSingle( int count )
 {
   FIX::ClOrdID clOrdID( "ORDERID" );
   FIX::HandlInst handlInst( '1' );
@@ -584,18 +668,17 @@ int testValidateDictNewOrderSingle( int count )
   message.getHeader().set( FIX::TargetCompID( "TARGET" ) );
   message.getHeader().set( FIX::MsgSeqNum( 1 ) );
 
-  FIX::DataDictionary dataDictionary( "../spec/FIX42.xml" );
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
   {
-    dataDictionary.validate( message );
+    s_dataDictionary->validate( message );
   }
   return GetTickCount() - start;
 }
 
-int testValidateQuoteRequest( int count )
+long testValidateQuoteRequest( int count )
 {
   FIX42::QuoteRequest message( FIX::QuoteReqID("1") );
   FIX42::QuoteRequest::NoRelatedSym noRelatedSym;
@@ -616,7 +699,7 @@ int testValidateQuoteRequest( int count )
   FIX::DataDictionary dataDictionary;
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int j = 0; j <= count; ++j )
   {
     dataDictionary.validate( message );
@@ -624,7 +707,7 @@ int testValidateQuoteRequest( int count )
   return GetTickCount() - start;
 }
 
-int testValidateDictQuoteRequest( int count )
+long testValidateDictQuoteRequest( int count )
 {
   FIX42::QuoteRequest message( FIX::QuoteReqID("1") );
   FIX42::QuoteRequest::NoRelatedSym noRelatedSym;
@@ -642,13 +725,12 @@ int testValidateDictQuoteRequest( int count )
     message.addGroup( noRelatedSym );
   }
 
-  FIX::DataDictionary dataDictionary( "../spec/FIX42.xml" );
   count = count - 1;
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int j = 0; j <= count; ++j )
   {
-    dataDictionary.validate( message );
+    s_dataDictionary->validate( message );
   }
   return GetTickCount() - start;
 }
@@ -670,7 +752,7 @@ private:
   int m_count;
 };
 
-int testSendOnSocket( int count, short port )
+long testSendOnSocket( int count, short port )
 {
   std::stringstream stream;
   stream
@@ -717,7 +799,7 @@ int testSendOnSocket( int count, short port )
 
   FIX::process_sleep( 1 );
 
-  int start = GetTickCount();
+  long start = GetTickCount();
 
   for ( int i = 0; i <= count; ++i )
     FIX::Session::sendToTarget( message, sessionID );
@@ -725,7 +807,7 @@ int testSendOnSocket( int count, short port )
   while( application.getCount() < count )
     FIX::process_sleep( 0.1 );
 
-  int ticks = GetTickCount() - start;
+  long ticks = GetTickCount() - start;
 
   initiator.stop();
   acceptor.stop();
@@ -733,7 +815,7 @@ int testSendOnSocket( int count, short port )
   return ticks;
 }
 
-int testSendOnThreadedSocket( int count, short port )
+long testSendOnThreadedSocket( int count, short port )
 {
   std::stringstream stream;
   stream
@@ -779,14 +861,14 @@ int testSendOnThreadedSocket( int count, short port )
 
   FIX::process_sleep( 1 );
 
-  int start = GetTickCount();
+  long start = GetTickCount();
   for ( int i = 0; i <= count; ++i )
     FIX::Session::sendToTarget( message, sessionID );
 
   while( application.getCount() < count )
     FIX::process_sleep( 0.1 );
 
-  int ticks = GetTickCount() - start;
+  long ticks = GetTickCount() - start;
 
   initiator.stop();
   acceptor.stop();
