@@ -1,5 +1,5 @@
 require 'quickfix'
-module Quickfix42Sp0
+module Quickfix42
 class Message < Quickfix::Message
 	def initialize
 		super
@@ -49,7 +49,7 @@ class Logout < Message
 	end
 end
 
-class IndicationofInterest < Message
+class IOI < Message
 	def initialize
 		super
 		getHeader().setField( Quickfix::MsgType.new("6") )
@@ -529,7 +529,7 @@ class ListStatus < Message
 	end
 end
 
-class AllocationACK < Message
+class AllocationInstructionAck < Message
 	def initialize
 		super
 		getHeader().setField( Quickfix::MsgType.new("P") )
